Class: SnapTrade::AccountHoldingsAccount
- Inherits:
-
Object
- Object
- SnapTrade::AccountHoldingsAccount
- Defined in:
- lib/snaptrade/models/account_holdings_account.rb
Overview
A wrapper object containing holdings information for a single account.
Instance Attribute Summary collapse
-
#account ⇒ Object
Returns the value of attribute account.
-
#balances ⇒ Object
List of balances for the account.
-
#option_positions ⇒ Object
List of option positions in the account.
-
#orders ⇒ Object
List of recent orders in the account, including both pending and executed orders.
-
#positions ⇒ Object
List of stock/ETF/crypto/mutual fund positions in the account.
-
#total_value ⇒ Object
Returns the value of attribute total_value.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AccountHoldingsAccount
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AccountHoldingsAccount
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/snaptrade/models/account_holdings_account.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SnapTrade::AccountHoldingsAccount` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SnapTrade::AccountHoldingsAccount`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account') self.account = attributes[:'account'] end if attributes.key?(:'balances') if (value = attributes[:'balances']).is_a?(Array) self.balances = value end end if attributes.key?(:'positions') if (value = attributes[:'positions']).is_a?(Array) self.positions = value end end if attributes.key?(:'option_positions') if (value = attributes[:'option_positions']).is_a?(Array) self.option_positions = value end end if attributes.key?(:'orders') if (value = attributes[:'orders']).is_a?(Array) self.orders = value end end if attributes.key?(:'total_value') self.total_value = attributes[:'total_value'] end end |
Instance Attribute Details
#account ⇒ Object
Returns the value of attribute account.
16 17 18 |
# File 'lib/snaptrade/models/account_holdings_account.rb', line 16 def account @account end |
#balances ⇒ Object
List of balances for the account. Each element of the list has a distinct currency. Some brokerages like Questrade [allows holding multiple currencies in the same account](www.questrade.com/learning/questrade-basics/balances-and-reports/understanding-your-account-balances).
19 20 21 |
# File 'lib/snaptrade/models/account_holdings_account.rb', line 19 def balances @balances end |
#option_positions ⇒ Object
List of option positions in the account.
25 26 27 |
# File 'lib/snaptrade/models/account_holdings_account.rb', line 25 def option_positions @option_positions end |
#orders ⇒ Object
List of recent orders in the account, including both pending and executed orders. Note that option orders are included in this list. Option orders will have a null ‘universal_symbol` field and a non-null `option_symbol` field.
28 29 30 |
# File 'lib/snaptrade/models/account_holdings_account.rb', line 28 def orders @orders end |
#positions ⇒ Object
List of stock/ETF/crypto/mutual fund positions in the account.
22 23 24 |
# File 'lib/snaptrade/models/account_holdings_account.rb', line 22 def positions @positions end |
#total_value ⇒ Object
Returns the value of attribute total_value.
30 31 32 |
# File 'lib/snaptrade/models/account_holdings_account.rb', line 30 def total_value @total_value end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
45 46 47 |
# File 'lib/snaptrade/models/account_holdings_account.rb', line 45 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 |
# File 'lib/snaptrade/models/account_holdings_account.rb', line 33 def self.attribute_map { :'account' => :'account', :'balances' => :'balances', :'positions' => :'positions', :'option_positions' => :'option_positions', :'orders' => :'orders', :'total_value' => :'total_value' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
160 161 162 |
# File 'lib/snaptrade/models/account_holdings_account.rb', line 160 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
62 63 64 65 66 67 68 69 |
# File 'lib/snaptrade/models/account_holdings_account.rb', line 62 def self.openapi_nullable Set.new([ :'balances', :'positions', :'option_positions', :'orders', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 59 |
# File 'lib/snaptrade/models/account_holdings_account.rb', line 50 def self.openapi_types { :'account' => :'Account', :'balances' => :'Array<Balance>', :'positions' => :'Array<Position>', :'option_positions' => :'Array<OptionsPosition>', :'orders' => :'Array<AccountOrderRecord>', :'total_value' => :'SnapTradeHoldingsTotalValue' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
134 135 136 137 138 139 140 141 142 143 |
# File 'lib/snaptrade/models/account_holdings_account.rb', line 134 def ==(o) return true if self.equal?(o) self.class == o.class && account == o.account && balances == o.balances && positions == o.positions && option_positions == o.option_positions && orders == o.orders && total_value == o.total_value end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/snaptrade/models/account_holdings_account.rb', line 191 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = SnapTrade.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/snaptrade/models/account_holdings_account.rb', line 262 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/snaptrade/models/account_holdings_account.rb', line 167 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
147 148 149 |
# File 'lib/snaptrade/models/account_holdings_account.rb', line 147 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
153 154 155 |
# File 'lib/snaptrade/models/account_holdings_account.rb', line 153 def hash [account, balances, positions, option_positions, orders, total_value].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
121 122 123 124 |
# File 'lib/snaptrade/models/account_holdings_account.rb', line 121 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
238 239 240 |
# File 'lib/snaptrade/models/account_holdings_account.rb', line 238 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/snaptrade/models/account_holdings_account.rb', line 244 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
232 233 234 |
# File 'lib/snaptrade/models/account_holdings_account.rb', line 232 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
128 129 130 |
# File 'lib/snaptrade/models/account_holdings_account.rb', line 128 def valid? true end |