Class: SnapTrade::AccountUniversalActivity

Inherits:
Object
  • Object
show all
Defined in:
lib/snaptrade/models/account_universal_activity.rb

Overview

A transaction or activity from an institution

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AccountUniversalActivity

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/snaptrade/models/account_universal_activity.rb', line 124

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SnapTrade::AccountUniversalActivity` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SnapTrade::AccountUniversalActivity`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'symbol')
    self.symbol = attributes[:'symbol']
  end

  if attributes.key?(:'option_symbol')
    self.option_symbol = attributes[:'option_symbol']
  end

  if attributes.key?(:'price')
    self.price = attributes[:'price']
  end

  if attributes.key?(:'units')
    self.units = attributes[:'units']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'option_type')
    self.option_type = attributes[:'option_type']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'trade_date')
    self.trade_date = attributes[:'trade_date']
  end

  if attributes.key?(:'settlement_date')
    self.settlement_date = attributes[:'settlement_date']
  end

  if attributes.key?(:'fee')
    self.fee = attributes[:'fee']
  end

  if attributes.key?(:'fx_rate')
    self.fx_rate = attributes[:'fx_rate']
  end

  if attributes.key?(:'institution')
    self.institution = attributes[:'institution']
  end

  if attributes.key?(:'external_reference_id')
    self.external_reference_id = attributes[:'external_reference_id']
  end
end

Instance Attribute Details

#amountObject

The amount of the transaction denominated in ‘currency`. This can be positive or negative. In general, transactions that positively affect the account balance (like sell, deposits, dividends, etc) will have a positive amount, while transactions that negatively affect the account balance (like buy, withdrawals, fees, etc) will have a negative amount.



30
31
32
# File 'lib/snaptrade/models/account_universal_activity.rb', line 30

def amount
  @amount
end

#currencyObject

Returns the value of attribute currency.



32
33
34
# File 'lib/snaptrade/models/account_universal_activity.rb', line 32

def currency
  @currency
end

#descriptionObject

A human-readable description of the transaction. This is usually the brokerage’s description of the transaction.



41
42
43
# File 'lib/snaptrade/models/account_universal_activity.rb', line 41

def description
  @description
end

#external_reference_idObject

Reference ID from brokerage used to identify related transactions. For example if an order comprises of several transactions (buy, fee, fx), they can be grouped if they share the same ‘external_reference_id`



59
60
61
# File 'lib/snaptrade/models/account_universal_activity.rb', line 59

def external_reference_id
  @external_reference_id
end

#feeObject

Any fee associated with the transaction if provided by the brokerage.



50
51
52
# File 'lib/snaptrade/models/account_universal_activity.rb', line 50

def fee
  @fee
end

#fx_rateObject

The forex conversion rate involved in the transaction if provided by the brokerage. Used in cases where securities of one currency are purchased in a different currency, and the forex conversion is automatic. In those cases, price, amount and fee will be in the top level currency (activity -> currency)



53
54
55
# File 'lib/snaptrade/models/account_universal_activity.rb', line 53

def fx_rate
  @fx_rate
end

#idObject

Unique identifier for the transaction. This is the ID used to reference the transaction in SnapTrade. Please note that this ID can change if the transaction is deleted and re-added. Under normal circumstances, SnapTrade does not delete transactions. The only time this would happen is if SnapTrade re-fetches and reprocesses the data from the brokerage, which is rare. If you require a stable ID, please let us know and we can work with you to provide one.



17
18
19
# File 'lib/snaptrade/models/account_universal_activity.rb', line 17

def id
  @id
end

#institutionObject

The institution that the transaction is associated with. This is usually the brokerage name.



56
57
58
# File 'lib/snaptrade/models/account_universal_activity.rb', line 56

def institution
  @institution
end

#option_symbolObject

Returns the value of attribute option_symbol.



21
22
23
# File 'lib/snaptrade/models/account_universal_activity.rb', line 21

def option_symbol
  @option_symbol
end

#option_typeObject

If an option ‘BUY` or `SELL` transaction, this further specifies the type of action. The possible values are: - BUY_TO_OPEN - BUY_TO_CLOSE - SELL_TO_OPEN - SELL_TO_CLOSE



38
39
40
# File 'lib/snaptrade/models/account_universal_activity.rb', line 38

def option_type
  @option_type
end

#priceObject

The price of the security for the transaction. This is mostly applicable to ‘BUY`, `SELL`, and `DIVIDEND` transactions.



24
25
26
# File 'lib/snaptrade/models/account_universal_activity.rb', line 24

def price
  @price
end

#settlement_dateObject

The date on which the transaction is settled.



47
48
49
# File 'lib/snaptrade/models/account_universal_activity.rb', line 47

def settlement_date
  @settlement_date
end

#symbolObject

Returns the value of attribute symbol.



19
20
21
# File 'lib/snaptrade/models/account_universal_activity.rb', line 19

def symbol
  @symbol
end

#trade_dateObject

The recorded time for the transaction. The granularity of this timestamp depends on the brokerage. Some brokerages provide the exact time of the transaction, while others provide only the date. Please check the [integrations page](snaptrade.notion.site/66793431ad0b416489eaabaf248d0afb?v=6fab8012ade6441fa0c6d9af9c55ce3a) for the specific brokerage to see the granularity of the timestamps. Note that even though the field is named ‘trade_date`, it can represent any type of transaction, not just trades.



44
45
46
# File 'lib/snaptrade/models/account_universal_activity.rb', line 44

def trade_date
  @trade_date
end

#typeObject

A string representing the type of transaction. SnapTrade does a best effort to categorize the brokerage transaction types into a common set of values. Here are some of the most popular values: - ‘BUY` - Asset bought. - `SELL` - Asset sold. - `DIVIDEND` - Dividend payout. - `CONTRIBUTION` - Cash contribution. - `WITHDRAWAL` - Cash withdrawal. - `REI` - Dividend reinvestment. - `STOCK_DIVIDEND` - A type of dividend where a company distributes shares instead of cash - `INTEREST` - Interest deposited into the account. - `FEE` - Fee withdrawn from the account. - `TAX` - A tax related fee. - `OPTIONEXPIRATION` - Option expiration event. - `OPTIONASSIGNMENT` - Option assignment event. - `OPTIONEXERCISE` - Option exercise event. - `TRANSFER` - Transfer of asset(s) from one account to another. - `EXTERNAL_ASSET_TRANSFER_IN` - Incoming transfer of an asset from an external account to this account. - `EXTERNAL_ASSET_TRANSFER_OUT` - Outgoing transfer of an asset from this account to an external account. - `SPLIT` - A stock share split. - `ADJUSTMENT` - A one time adjustment of the account’s cash balance or shares of an asset



35
36
37
# File 'lib/snaptrade/models/account_universal_activity.rb', line 35

def type
  @type
end

#unitsObject

The number of units of the security for the transaction. This is mostly applicable to ‘BUY`, `SELL`, and `DIVIDEND` transactions.



27
28
29
# File 'lib/snaptrade/models/account_universal_activity.rb', line 27

def units
  @units
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/snaptrade/models/account_universal_activity.rb', line 84

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/snaptrade/models/account_universal_activity.rb', line 62

def self.attribute_map
  {
    :'id' => :'id',
    :'symbol' => :'symbol',
    :'option_symbol' => :'option_symbol',
    :'price' => :'price',
    :'units' => :'units',
    :'amount' => :'amount',
    :'currency' => :'currency',
    :'type' => :'type',
    :'option_type' => :'option_type',
    :'description' => :'description',
    :'trade_date' => :'trade_date',
    :'settlement_date' => :'settlement_date',
    :'fee' => :'fee',
    :'fx_rate' => :'fx_rate',
    :'institution' => :'institution',
    :'external_reference_id' => :'external_reference_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



253
254
255
# File 'lib/snaptrade/models/account_universal_activity.rb', line 253

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



111
112
113
114
115
116
117
118
119
120
# File 'lib/snaptrade/models/account_universal_activity.rb', line 111

def self.openapi_nullable
  Set.new([
    :'symbol',
    :'option_symbol',
    :'amount',
    :'trade_date',
    :'fx_rate',
    :'external_reference_id'
  ])
end

.openapi_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/snaptrade/models/account_universal_activity.rb', line 89

def self.openapi_types
  {
    :'id' => :'String',
    :'symbol' => :'AccountUniversalActivitySymbol',
    :'option_symbol' => :'AccountUniversalActivityOptionSymbol',
    :'price' => :'Float',
    :'units' => :'Float',
    :'amount' => :'Float',
    :'currency' => :'AccountUniversalActivityCurrency',
    :'type' => :'String',
    :'option_type' => :'String',
    :'description' => :'String',
    :'trade_date' => :'Time',
    :'settlement_date' => :'Time',
    :'fee' => :'Float',
    :'fx_rate' => :'Float',
    :'institution' => :'String',
    :'external_reference_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/snaptrade/models/account_universal_activity.rb', line 217

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      symbol == o.symbol &&
      option_symbol == o.option_symbol &&
      price == o.price &&
      units == o.units &&
      amount == o.amount &&
      currency == o.currency &&
      type == o.type &&
      option_type == o.option_type &&
      description == o.description &&
      trade_date == o.trade_date &&
      settlement_date == o.settlement_date &&
      fee == o.fee &&
      fx_rate == o.fx_rate &&
      institution == o.institution &&
      external_reference_id == o.external_reference_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/snaptrade/models/account_universal_activity.rb', line 284

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = SnapTrade.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/snaptrade/models/account_universal_activity.rb', line 355

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/snaptrade/models/account_universal_activity.rb', line 260

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


240
241
242
# File 'lib/snaptrade/models/account_universal_activity.rb', line 240

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



246
247
248
# File 'lib/snaptrade/models/account_universal_activity.rb', line 246

def hash
  [id, symbol, option_symbol, price, units, amount, currency, type, option_type, description, trade_date, settlement_date, fee, fx_rate, institution, external_reference_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



204
205
206
207
# File 'lib/snaptrade/models/account_universal_activity.rb', line 204

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



331
332
333
# File 'lib/snaptrade/models/account_universal_activity.rb', line 331

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/snaptrade/models/account_universal_activity.rb', line 337

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



325
326
327
# File 'lib/snaptrade/models/account_universal_activity.rb', line 325

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



211
212
213
# File 'lib/snaptrade/models/account_universal_activity.rb', line 211

def valid?
  true
end