Class: SnapTrade::AccountUniversalActivityOptionSymbol
- Inherits:
-
Object
- Object
- SnapTrade::AccountUniversalActivityOptionSymbol
- Defined in:
- lib/snaptrade/models/account_universal_activity_option_symbol.rb
Overview
The option security for the transaction. The field is ‘null` if the transaction is not related to an option security (like a deposit, withdrawal, fee, etc). SnapTrade does a best effort to map the brokerage’s option symbol. In cases where the brokerage option symbol is not recognized, the field will be set to ‘null`.
Instance Attribute Summary collapse
-
#expiration_date ⇒ Object
The option expiration date.
-
#id ⇒ Object
Unique identifier for the option symbol within SnapTrade.
-
#is_mini_option ⇒ Object
Whether the option is a mini option.
-
#option_type ⇒ Object
The type of option.
-
#strike_price ⇒ Object
The option strike price.
-
#ticker ⇒ Object
The [OCC symbol](en.wikipedia.org/wiki/Option_symbol) for the option.
-
#underlying_symbol ⇒ Object
Returns the value of attribute underlying_symbol.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AccountUniversalActivityOptionSymbol
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AccountUniversalActivityOptionSymbol
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/snaptrade/models/account_universal_activity_option_symbol.rb', line 82 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SnapTrade::AccountUniversalActivityOptionSymbol` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SnapTrade::AccountUniversalActivityOptionSymbol`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'ticker') self.ticker = attributes[:'ticker'] end if attributes.key?(:'option_type') self.option_type = attributes[:'option_type'] end if attributes.key?(:'strike_price') self.strike_price = attributes[:'strike_price'] end if attributes.key?(:'expiration_date') self.expiration_date = attributes[:'expiration_date'] end if attributes.key?(:'is_mini_option') self.is_mini_option = attributes[:'is_mini_option'] end if attributes.key?(:'underlying_symbol') self. = attributes[:'underlying_symbol'] end end |
Instance Attribute Details
#expiration_date ⇒ Object
The option expiration date.
29 30 31 |
# File 'lib/snaptrade/models/account_universal_activity_option_symbol.rb', line 29 def expiration_date @expiration_date end |
#id ⇒ Object
Unique identifier for the option symbol within SnapTrade. This is the ID used to reference the symbol in SnapTrade API calls.
17 18 19 |
# File 'lib/snaptrade/models/account_universal_activity_option_symbol.rb', line 17 def id @id end |
#is_mini_option ⇒ Object
Whether the option is a mini option. Mini options have 10 underlying shares per contract instead of the standard 100.
32 33 34 |
# File 'lib/snaptrade/models/account_universal_activity_option_symbol.rb', line 32 def is_mini_option @is_mini_option end |
#option_type ⇒ Object
The type of option. Either "CALL" or "PUT".
23 24 25 |
# File 'lib/snaptrade/models/account_universal_activity_option_symbol.rb', line 23 def option_type @option_type end |
#strike_price ⇒ Object
The option strike price.
26 27 28 |
# File 'lib/snaptrade/models/account_universal_activity_option_symbol.rb', line 26 def strike_price @strike_price end |
#ticker ⇒ Object
The [OCC symbol](en.wikipedia.org/wiki/Option_symbol) for the option.
20 21 22 |
# File 'lib/snaptrade/models/account_universal_activity_option_symbol.rb', line 20 def ticker @ticker end |
#underlying_symbol ⇒ Object
Returns the value of attribute underlying_symbol.
34 35 36 |
# File 'lib/snaptrade/models/account_universal_activity_option_symbol.rb', line 34 def @underlying_symbol end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/snaptrade/models/account_universal_activity_option_symbol.rb', line 50 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/snaptrade/models/account_universal_activity_option_symbol.rb', line 37 def self.attribute_map { :'id' => :'id', :'ticker' => :'ticker', :'option_type' => :'option_type', :'strike_price' => :'strike_price', :'expiration_date' => :'expiration_date', :'is_mini_option' => :'is_mini_option', :'underlying_symbol' => :'underlying_symbol' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
196 197 198 |
# File 'lib/snaptrade/models/account_universal_activity_option_symbol.rb', line 196 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
74 75 76 77 78 |
# File 'lib/snaptrade/models/account_universal_activity_option_symbol.rb', line 74 def self.openapi_all_of [ :'OptionsSymbol' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
68 69 70 71 |
# File 'lib/snaptrade/models/account_universal_activity_option_symbol.rb', line 68 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/snaptrade/models/account_universal_activity_option_symbol.rb', line 55 def self.openapi_types { :'id' => :'String', :'ticker' => :'String', :'option_type' => :'OptionType', :'strike_price' => :'Float', :'expiration_date' => :'Date', :'is_mini_option' => :'Boolean', :'underlying_symbol' => :'UnderlyingSymbol' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/snaptrade/models/account_universal_activity_option_symbol.rb', line 169 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && ticker == o.ticker && option_type == o.option_type && strike_price == o.strike_price && expiration_date == o.expiration_date && is_mini_option == o.is_mini_option && == o. end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/snaptrade/models/account_universal_activity_option_symbol.rb', line 227 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = SnapTrade.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/snaptrade/models/account_universal_activity_option_symbol.rb', line 298 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/snaptrade/models/account_universal_activity_option_symbol.rb', line 203 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
183 184 185 |
# File 'lib/snaptrade/models/account_universal_activity_option_symbol.rb', line 183 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
189 190 191 |
# File 'lib/snaptrade/models/account_universal_activity_option_symbol.rb', line 189 def hash [id, ticker, option_type, strike_price, expiration_date, is_mini_option, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/snaptrade/models/account_universal_activity_option_symbol.rb', line 126 def list_invalid_properties invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @ticker.nil? invalid_properties.push('invalid value for "ticker", ticker cannot be nil.') end if @option_type.nil? invalid_properties.push('invalid value for "option_type", option_type cannot be nil.') end if @strike_price.nil? invalid_properties.push('invalid value for "strike_price", strike_price cannot be nil.') end if @expiration_date.nil? invalid_properties.push('invalid value for "expiration_date", expiration_date cannot be nil.') end if @underlying_symbol.nil? invalid_properties.push('invalid value for "underlying_symbol", underlying_symbol cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
274 275 276 |
# File 'lib/snaptrade/models/account_universal_activity_option_symbol.rb', line 274 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/snaptrade/models/account_universal_activity_option_symbol.rb', line 280 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
268 269 270 |
# File 'lib/snaptrade/models/account_universal_activity_option_symbol.rb', line 268 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
157 158 159 160 161 162 163 164 165 |
# File 'lib/snaptrade/models/account_universal_activity_option_symbol.rb', line 157 def valid? return false if @id.nil? return false if @ticker.nil? return false if @option_type.nil? return false if @strike_price.nil? return false if @expiration_date.nil? return false if @underlying_symbol.nil? true end |