Class: SnapTrade::Brokerage

Inherits:
Object
  • Object
show all
Defined in:
lib/snaptrade/models/brokerage.rb

Overview

Describes a brokerage that SnapTrade supports.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Brokerage

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/snaptrade/models/brokerage.rb', line 135

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SnapTrade::Brokerage` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SnapTrade::Brokerage`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'slug')
    self.slug = attributes[:'slug']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'aws_s3_logo_url')
    self.aws_s3_logo_url = attributes[:'aws_s3_logo_url']
  end

  if attributes.key?(:'aws_s3_square_logo_url')
    self.aws_s3_square_logo_url = attributes[:'aws_s3_square_logo_url']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end

  if attributes.key?(:'maintenance_mode')
    self.maintenance_mode = attributes[:'maintenance_mode']
  end

  if attributes.key?(:'is_degraded')
    self.is_degraded = attributes[:'is_degraded']
  end

  if attributes.key?(:'allows_trading')
    self.allows_trading = attributes[:'allows_trading']
  end

  if attributes.key?(:'allows_fractional_units')
    self.allows_fractional_units = attributes[:'allows_fractional_units']
  end

  if attributes.key?(:'has_reporting')
    self.has_reporting = attributes[:'has_reporting']
  end

  if attributes.key?(:'is_real_time_connection')
    self.is_real_time_connection = attributes[:'is_real_time_connection']
  end

  if attributes.key?(:'brokerage_type')
    self.brokerage_type = attributes[:'brokerage_type']
  end

  if attributes.key?(:'exchanges')
    if (value = attributes[:'exchanges']).is_a?(Array)
      self.exchanges = value
    end
  end

  if attributes.key?(:'open_url')
    self.open_url = attributes[:'open_url']
  end
end

Instance Attribute Details

#allows_fractional_unitsObject

This field is deprecated. Please contact us if you have a valid use case for it.



53
54
55
# File 'lib/snaptrade/models/brokerage.rb', line 53

def allows_fractional_units
  @allows_fractional_units
end

#allows_tradingObject

Whether the brokerage allows trading through SnapTrade.



50
51
52
# File 'lib/snaptrade/models/brokerage.rb', line 50

def allows_trading
  @allows_trading
end

#aws_s3_logo_urlObject

URL to the brokerage’s logo.



32
33
34
# File 'lib/snaptrade/models/brokerage.rb', line 32

def aws_s3_logo_url
  @aws_s3_logo_url
end

#aws_s3_square_logo_urlObject

URL to the brokerage’s logo in square format.



35
36
37
# File 'lib/snaptrade/models/brokerage.rb', line 35

def aws_s3_square_logo_url
  @aws_s3_square_logo_url
end

#brokerage_typeObject

Returns the value of attribute brokerage_type.



61
62
63
# File 'lib/snaptrade/models/brokerage.rb', line 61

def brokerage_type
  @brokerage_type
end

#descriptionObject

A brief description of the brokerage.



29
30
31
# File 'lib/snaptrade/models/brokerage.rb', line 29

def description
  @description
end

#display_nameObject

A display-friendly name of the brokerage.



26
27
28
# File 'lib/snaptrade/models/brokerage.rb', line 26

def display_name
  @display_name
end

#enabledObject

Whether the brokerage is enabled in SnapTrade. A disabled brokerage will not be available for new connections.



41
42
43
# File 'lib/snaptrade/models/brokerage.rb', line 41

def enabled
  @enabled
end

#exchangesObject

This field is deprecated. Please contact us if you have a valid use case for it.



64
65
66
# File 'lib/snaptrade/models/brokerage.rb', line 64

def exchanges
  @exchanges
end

#has_reportingObject

This field is deprecated. Please contact us if you have a valid use case for it.



56
57
58
# File 'lib/snaptrade/models/brokerage.rb', line 56

def has_reporting
  @has_reporting
end

#idObject

Unique identifier for the brokerage firm. This is the UUID used to reference the brokerage in SnapTrade.



17
18
19
# File 'lib/snaptrade/models/brokerage.rb', line 17

def id
  @id
end

#is_degradedObject

Whether the brokerage is currently degraded. A degraded brokerage may have reduced functionality or be experiencing technical issues.



47
48
49
# File 'lib/snaptrade/models/brokerage.rb', line 47

def is_degraded
  @is_degraded
end

#is_real_time_connectionObject

This field is deprecated. Please contact us if you have a valid use case for it.



59
60
61
# File 'lib/snaptrade/models/brokerage.rb', line 59

def is_real_time_connection
  @is_real_time_connection
end

#maintenance_modeObject

Whether the brokerage is currently in maintenance mode. A brokerage in maintenance mode will not be available for new connections.



44
45
46
# File 'lib/snaptrade/models/brokerage.rb', line 44

def maintenance_mode
  @maintenance_mode
end

#nameObject

Full name of the brokerage.



23
24
25
# File 'lib/snaptrade/models/brokerage.rb', line 23

def name
  @name
end

#open_urlObject

This field is deprecated.



67
68
69
# File 'lib/snaptrade/models/brokerage.rb', line 67

def open_url
  @open_url
end

#slugObject

A short, unique identifier for the brokerage. It is usually the name of the brokerage in capital letters and will never change.



20
21
22
# File 'lib/snaptrade/models/brokerage.rb', line 20

def slug
  @slug
end

#urlObject

URL to the brokerage’s website.



38
39
40
# File 'lib/snaptrade/models/brokerage.rb', line 38

def url
  @url
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



94
95
96
# File 'lib/snaptrade/models/brokerage.rb', line 94

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/snaptrade/models/brokerage.rb', line 70

def self.attribute_map
  {
    :'id' => :'id',
    :'slug' => :'slug',
    :'name' => :'name',
    :'display_name' => :'display_name',
    :'description' => :'description',
    :'aws_s3_logo_url' => :'aws_s3_logo_url',
    :'aws_s3_square_logo_url' => :'aws_s3_square_logo_url',
    :'url' => :'url',
    :'enabled' => :'enabled',
    :'maintenance_mode' => :'maintenance_mode',
    :'is_degraded' => :'is_degraded',
    :'allows_trading' => :'allows_trading',
    :'allows_fractional_units' => :'allows_fractional_units',
    :'has_reporting' => :'has_reporting',
    :'is_real_time_connection' => :'is_real_time_connection',
    :'brokerage_type' => :'brokerage_type',
    :'exchanges' => :'exchanges',
    :'open_url' => :'open_url'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



276
277
278
# File 'lib/snaptrade/models/brokerage.rb', line 276

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



123
124
125
126
127
128
129
130
131
# File 'lib/snaptrade/models/brokerage.rb', line 123

def self.openapi_nullable
  Set.new([
    :'aws_s3_square_logo_url',
    :'allows_trading',
    :'allows_fractional_units',
    :'has_reporting',
    :'open_url'
  ])
end

.openapi_typesObject

Attribute type mapping.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/snaptrade/models/brokerage.rb', line 99

def self.openapi_types
  {
    :'id' => :'String',
    :'slug' => :'String',
    :'name' => :'String',
    :'display_name' => :'String',
    :'description' => :'String',
    :'aws_s3_logo_url' => :'String',
    :'aws_s3_square_logo_url' => :'String',
    :'url' => :'String',
    :'enabled' => :'Boolean',
    :'maintenance_mode' => :'Boolean',
    :'is_degraded' => :'Boolean',
    :'allows_trading' => :'Boolean',
    :'allows_fractional_units' => :'Boolean',
    :'has_reporting' => :'Boolean',
    :'is_real_time_connection' => :'Boolean',
    :'brokerage_type' => :'BrokerageType',
    :'exchanges' => :'Array<Object>',
    :'open_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/snaptrade/models/brokerage.rb', line 238

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      slug == o.slug &&
      name == o.name &&
      display_name == o.display_name &&
      description == o.description &&
      aws_s3_logo_url == o.aws_s3_logo_url &&
      aws_s3_square_logo_url == o.aws_s3_square_logo_url &&
      url == o.url &&
      enabled == o.enabled &&
      maintenance_mode == o.maintenance_mode &&
      is_degraded == o.is_degraded &&
      allows_trading == o.allows_trading &&
      allows_fractional_units == o.allows_fractional_units &&
      has_reporting == o.has_reporting &&
      is_real_time_connection == o.is_real_time_connection &&
      brokerage_type == o.brokerage_type &&
      exchanges == o.exchanges &&
      open_url == o.open_url
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/snaptrade/models/brokerage.rb', line 307

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = SnapTrade.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/snaptrade/models/brokerage.rb', line 378

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/snaptrade/models/brokerage.rb', line 283

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


263
264
265
# File 'lib/snaptrade/models/brokerage.rb', line 263

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



269
270
271
# File 'lib/snaptrade/models/brokerage.rb', line 269

def hash
  [id, slug, name, display_name, description, aws_s3_logo_url, aws_s3_square_logo_url, url, enabled, maintenance_mode, is_degraded, allows_trading, allows_fractional_units, has_reporting, is_real_time_connection, brokerage_type, exchanges, open_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



225
226
227
228
# File 'lib/snaptrade/models/brokerage.rb', line 225

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



354
355
356
# File 'lib/snaptrade/models/brokerage.rb', line 354

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



360
361
362
363
364
365
366
367
368
369
370
371
372
# File 'lib/snaptrade/models/brokerage.rb', line 360

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



348
349
350
# File 'lib/snaptrade/models/brokerage.rb', line 348

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



232
233
234
# File 'lib/snaptrade/models/brokerage.rb', line 232

def valid?
  true
end