Class: SnapTrade::ComplexOrderLeg

Inherits:
Object
  • Object
show all
Defined in:
lib/snaptrade/models/complex_order_leg.rb

Overview

A single leg within a complex order.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ComplexOrderLeg

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/snaptrade/models/complex_order_leg.rb', line 82

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SnapTrade::ComplexOrderLeg` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SnapTrade::ComplexOrderLeg`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'order_role')
    self.order_role = attributes[:'order_role']
  end

  if attributes.key?(:'action')
    self.action = attributes[:'action']
  end

  if attributes.key?(:'instrument')
    self.instrument = attributes[:'instrument']
  end

  if attributes.key?(:'order_type')
    self.order_type = attributes[:'order_type']
  end

  if attributes.key?(:'units')
    self.units = attributes[:'units']
  end

  if attributes.key?(:'time_in_force')
    self.time_in_force = attributes[:'time_in_force']
  end

  if attributes.key?(:'price')
    self.price = attributes[:'price']
  end

  if attributes.key?(:'stop')
    self.stop = attributes[:'stop']
  end
end

Instance Attribute Details

#actionObject

The action describes the intent or side of a trade. This is either ‘BUY` or `SELL`.



20
21
22
# File 'lib/snaptrade/models/complex_order_leg.rb', line 20

def action
  @action
end

#instrumentObject

Returns the value of attribute instrument.



22
23
24
# File 'lib/snaptrade/models/complex_order_leg.rb', line 22

def instrument
  @instrument
end

#order_roleObject

The role of this leg within the complex order.



17
18
19
# File 'lib/snaptrade/models/complex_order_leg.rb', line 17

def order_role
  @order_role
end

#order_typeObject

The type of order to place. - For ‘Limit` and `StopLimit` orders, the `price` field is required. - For `Stop` and `StopLimit` orders, the `stop` field is required.



25
26
27
# File 'lib/snaptrade/models/complex_order_leg.rb', line 25

def order_type
  @order_type
end

#priceObject

The limit price. Required when ‘order_type` is `Limit` or `StopLimit`.



34
35
36
# File 'lib/snaptrade/models/complex_order_leg.rb', line 34

def price
  @price
end

#stopObject

The stop trigger price. Required when ‘order_type` is `Stop` or `StopLimit`.



37
38
39
# File 'lib/snaptrade/models/complex_order_leg.rb', line 37

def stop
  @stop
end

#time_in_forceObject

The Time in Force type for the order. This field indicates how long the order will remain active before it is executed or expires. Here are the supported values: - ‘Day` - Day. The order is valid only for the trading day on which it is placed. - `GTC` - Good Til Canceled. The order is valid until it is executed or canceled. - `FOK` - Fill Or Kill. The order must be executed in its entirety immediately or be canceled completely. - `IOC` - Immediate Or Cancel. The order must be executed immediately. Any portion of the order that cannot be filled immediately will be canceled.



31
32
33
# File 'lib/snaptrade/models/complex_order_leg.rb', line 31

def time_in_force
  @time_in_force
end

#unitsObject

Number of shares for the order. This can be a decimal for fractional orders. Must be ‘null` if `notional_value` is provided.



28
29
30
# File 'lib/snaptrade/models/complex_order_leg.rb', line 28

def units
  @units
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/snaptrade/models/complex_order_leg.rb', line 54

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/snaptrade/models/complex_order_leg.rb', line 40

def self.attribute_map
  {
    :'order_role' => :'order_role',
    :'action' => :'action',
    :'instrument' => :'instrument',
    :'order_type' => :'order_type',
    :'units' => :'units',
    :'time_in_force' => :'time_in_force',
    :'price' => :'price',
    :'stop' => :'stop'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



201
202
203
# File 'lib/snaptrade/models/complex_order_leg.rb', line 201

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



73
74
75
76
77
78
# File 'lib/snaptrade/models/complex_order_leg.rb', line 73

def self.openapi_nullable
  Set.new([
    :'price',
    :'stop'
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/snaptrade/models/complex_order_leg.rb', line 59

def self.openapi_types
  {
    :'order_role' => :'OrderRole',
    :'action' => :'ActionStrict',
    :'instrument' => :'TradingInstrument',
    :'order_type' => :'OrderTypeStrict',
    :'units' => :'Float',
    :'time_in_force' => :'TimeInForceStrict',
    :'price' => :'Float',
    :'stop' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/snaptrade/models/complex_order_leg.rb', line 173

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      order_role == o.order_role &&
      action == o.action &&
      instrument == o.instrument &&
      order_type == o.order_type &&
      units == o.units &&
      time_in_force == o.time_in_force &&
      price == o.price &&
      stop == o.stop
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/snaptrade/models/complex_order_leg.rb', line 232

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = SnapTrade.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/snaptrade/models/complex_order_leg.rb', line 303

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/snaptrade/models/complex_order_leg.rb', line 208

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


188
189
190
# File 'lib/snaptrade/models/complex_order_leg.rb', line 188

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



194
195
196
# File 'lib/snaptrade/models/complex_order_leg.rb', line 194

def hash
  [order_role, action, instrument, order_type, units, time_in_force, price, stop].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/snaptrade/models/complex_order_leg.rb', line 130

def list_invalid_properties
  invalid_properties = Array.new
  if @order_role.nil?
    invalid_properties.push('invalid value for "order_role", order_role cannot be nil.')
  end

  if @action.nil?
    invalid_properties.push('invalid value for "action", action cannot be nil.')
  end

  if @instrument.nil?
    invalid_properties.push('invalid value for "instrument", instrument cannot be nil.')
  end

  if @order_type.nil?
    invalid_properties.push('invalid value for "order_type", order_type cannot be nil.')
  end

  if @units.nil?
    invalid_properties.push('invalid value for "units", units cannot be nil.')
  end

  if @time_in_force.nil?
    invalid_properties.push('invalid value for "time_in_force", time_in_force cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



279
280
281
# File 'lib/snaptrade/models/complex_order_leg.rb', line 279

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/snaptrade/models/complex_order_leg.rb', line 285

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



273
274
275
# File 'lib/snaptrade/models/complex_order_leg.rb', line 273

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



161
162
163
164
165
166
167
168
169
# File 'lib/snaptrade/models/complex_order_leg.rb', line 161

def valid?
  return false if @order_role.nil?
  return false if @action.nil?
  return false if @instrument.nil?
  return false if @order_type.nil?
  return false if @units.nil?
  return false if @time_in_force.nil?
  true
end