Class: SnapTrade::Configuration
- Inherits:
-
Object
- Object
- SnapTrade::Configuration
- Defined in:
- lib/snaptrade/configuration.rb
Instance Attribute Summary collapse
-
#api_key_prefix ⇒ Hash
Defines API key prefixes used with API Key authentications.
-
#api_key_store ⇒ Hash
Defines API keys used with API Key authentications.
-
#base_path ⇒ Object
Defines url base path.
-
#client_side_validation ⇒ true, false
Set this to false to skip client side validation in the operation.
-
#consumer_key ⇒ Object
client state configured through konfig.yaml.
-
#debugging ⇒ true, false
Set this to enable/disable debugging.
-
#force_ending_format ⇒ Object
Returns the value of attribute force_ending_format.
-
#host ⇒ Object
Defines url host.
-
#inject_format ⇒ Object
Returns the value of attribute inject_format.
-
#logger ⇒ #debug
Defines the logger used for debugging.
-
#params_encoder ⇒ Object
Set this to customize parameters encoder of array parameter.
-
#proxy ⇒ Object
Proxy setting HTTP Proxy settings.
-
#scheme ⇒ Object
Defines url scheme.
-
#server_index ⇒ Object
Define server configuration index.
-
#server_operation_index ⇒ Object
Define server operation configuration index.
-
#server_operation_variables ⇒ Object
Default server operation variables.
-
#server_variables ⇒ Object
Default server variables.
-
#ssl_ca_file ⇒ String
TLS/SSL setting Set this to customize the certificate file to verify the peer.
-
#ssl_client_cert ⇒ Object
TLS/SSL setting Client certificate file (for client certificate).
-
#ssl_client_key ⇒ Object
TLS/SSL setting Client private key file (for client certificate).
-
#ssl_verify ⇒ true, false
TLS/SSL setting Set this to false to skip verifying SSL certificate when calling API from https server.
-
#ssl_verify_mode ⇒ Object
TLS/SSL setting Any ‘OpenSSL::SSL::` constant (see ruby-doc.org/stdlib-2.5.1/libdoc/openssl/rdoc/OpenSSL/SSL.html).
-
#temp_folder_path ⇒ String
Defines the temporary folder to store downloaded files (for API endpoints that have file response).
-
#timeout ⇒ Object
The time limit for HTTP request in seconds.
Class Method Summary collapse
-
.default ⇒ Object
The default Configuration object.
Instance Method Summary collapse
-
#api_key_with_prefix(param_name, param_alias = nil) ⇒ Object
Gets API key (with prefix if set).
-
#auth_settings ⇒ Object
Returns Auth Settings hash for api client.
-
#base_url(operation = nil) ⇒ Object
Returns base URL for specified operation based on server settings.
- #client_id=(value) ⇒ Object
- #configure {|_self| ... } ⇒ Object
-
#configure_middleware(connection) ⇒ Object
Set up middleware on the connection.
-
#initialize {|_self| ... } ⇒ Configuration
constructor
A new instance of Configuration.
- #operation_server_settings ⇒ Object
-
#request(*middleware) ⇒ Object
Adds request middleware to the stack.
-
#response(*middleware) ⇒ Object
Adds response middleware to the stack.
-
#server_settings ⇒ Object
Returns an array of Server setting.
-
#server_url(index, variables = {}, servers = nil) ⇒ Object
Returns URL based on server settings.
-
#set_faraday_middleware(operation, key, *args, &block) ⇒ Object
Adds Faraday middleware setting information to the stack.
- #signature=(value) ⇒ Object
- #timestamp=(value) ⇒ Object
-
#use(*middleware) ⇒ Object
Adds middleware to the stack.
Constructor Details
#initialize {|_self| ... } ⇒ Configuration
Returns a new instance of Configuration.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/snaptrade/configuration.rb', line 146 def initialize @scheme = 'https' @host = 'api.snaptrade.com' @base_path = '/api/v1' @server_index = 0 @server_operation_index = {} @server_variables = {} @server_operation_variables = {} @api_key_store = {} @api_key_prefix = {} @client_side_validation = true @ssl_verify = true @ssl_verify_mode = nil @ssl_ca_file = nil @ssl_client_cert = nil @ssl_client_key = nil @middlewares = Hash.new { |h, k| h[k] = [] } @timeout = 60 # return data as binary instead of file @return_binary_data = false @params_encoder = nil @debugging = false @inject_format = false @force_ending_format = false @logger = defined?(Rails) ? Rails.logger : Logger.new(STDOUT) yield(self) if block_given? end |
Instance Attribute Details
#api_key_prefix ⇒ Hash
Defines API key prefixes used with API Key authentications.
69 70 71 |
# File 'lib/snaptrade/configuration.rb', line 69 def api_key_prefix @api_key_prefix end |
#api_key_store ⇒ Hash
Defines API keys used with API Key authentications.
61 62 63 |
# File 'lib/snaptrade/configuration.rb', line 61 def api_key_store @api_key_store end |
#base_path ⇒ Object
Defines url base path
19 20 21 |
# File 'lib/snaptrade/configuration.rb', line 19 def base_path @base_path end |
#client_side_validation ⇒ true, false
Set this to false to skip client side validation in the operation. Default to true.
98 99 100 |
# File 'lib/snaptrade/configuration.rb', line 98 def client_side_validation @client_side_validation end |
#consumer_key ⇒ Object
client state configured through konfig.yaml
46 47 48 |
# File 'lib/snaptrade/configuration.rb', line 46 def consumer_key @consumer_key end |
#debugging ⇒ true, false
Set this to enable/disable debugging. When enabled (set to true), HTTP request/response details will be logged with ‘logger.debug` (see the `logger` attribute). Default to false.
76 77 78 |
# File 'lib/snaptrade/configuration.rb', line 76 def debugging @debugging end |
#force_ending_format ⇒ Object
Returns the value of attribute force_ending_format.
144 145 146 |
# File 'lib/snaptrade/configuration.rb', line 144 def force_ending_format @force_ending_format end |
#host ⇒ Object
Defines url host
16 17 18 |
# File 'lib/snaptrade/configuration.rb', line 16 def host @host end |
#inject_format ⇒ Object
Returns the value of attribute inject_format.
142 143 144 |
# File 'lib/snaptrade/configuration.rb', line 142 def inject_format @inject_format end |
#logger ⇒ #debug
Defines the logger used for debugging. Default to ‘Rails.logger` (when in Rails) or logging to STDOUT.
82 83 84 |
# File 'lib/snaptrade/configuration.rb', line 82 def logger @logger end |
#params_encoder ⇒ Object
Set this to customize parameters encoder of array parameter. Default to nil. Faraday uses NestedParamsEncoder when nil.
github.com/lostisland/faraday/tree/main/lib/faraday/encoders
139 140 141 |
# File 'lib/snaptrade/configuration.rb', line 139 def params_encoder @params_encoder end |
#proxy ⇒ Object
Proxy setting HTTP Proxy settings
132 133 134 |
# File 'lib/snaptrade/configuration.rb', line 132 def proxy @proxy end |
#scheme ⇒ Object
Defines url scheme
13 14 15 |
# File 'lib/snaptrade/configuration.rb', line 13 def scheme @scheme end |
#server_index ⇒ Object
Define server configuration index
22 23 24 |
# File 'lib/snaptrade/configuration.rb', line 22 def server_index @server_index end |
#server_operation_index ⇒ Object
Define server operation configuration index
25 26 27 |
# File 'lib/snaptrade/configuration.rb', line 25 def server_operation_index @server_operation_index end |
#server_operation_variables ⇒ Object
Default server operation variables
31 32 33 |
# File 'lib/snaptrade/configuration.rb', line 31 def server_operation_variables @server_operation_variables end |
#server_variables ⇒ Object
Default server variables
28 29 30 |
# File 'lib/snaptrade/configuration.rb', line 28 def server_variables @server_variables end |
#ssl_ca_file ⇒ String
TLS/SSL setting Set this to customize the certificate file to verify the peer.
120 121 122 |
# File 'lib/snaptrade/configuration.rb', line 120 def ssl_ca_file @ssl_ca_file end |
#ssl_client_cert ⇒ Object
TLS/SSL setting Client certificate file (for client certificate)
124 125 126 |
# File 'lib/snaptrade/configuration.rb', line 124 def ssl_client_cert @ssl_client_cert end |
#ssl_client_key ⇒ Object
TLS/SSL setting Client private key file (for client certificate)
128 129 130 |
# File 'lib/snaptrade/configuration.rb', line 128 def ssl_client_key @ssl_client_key end |
#ssl_verify ⇒ true, false
Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.
TLS/SSL setting Set this to false to skip verifying SSL certificate when calling API from https server. Default to true.
107 108 109 |
# File 'lib/snaptrade/configuration.rb', line 107 def ssl_verify @ssl_verify end |
#ssl_verify_mode ⇒ Object
Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.
TLS/SSL setting Any ‘OpenSSL::SSL::` constant (see ruby-doc.org/stdlib-2.5.1/libdoc/openssl/rdoc/OpenSSL/SSL.html)
114 115 116 |
# File 'lib/snaptrade/configuration.rb', line 114 def ssl_verify_mode @ssl_verify_mode end |
#temp_folder_path ⇒ String
Defines the temporary folder to store downloaded files (for API endpoints that have file response). Default to use ‘Tempfile`.
89 90 91 |
# File 'lib/snaptrade/configuration.rb', line 89 def temp_folder_path @temp_folder_path end |
#timeout ⇒ Object
The time limit for HTTP request in seconds. Default to 0 (never times out).
93 94 95 |
# File 'lib/snaptrade/configuration.rb', line 93 def timeout @timeout end |
Class Method Details
.default ⇒ Object
The default Configuration object.
176 177 178 |
# File 'lib/snaptrade/configuration.rb', line 176 def self.default @@default ||= Configuration.new end |
Instance Method Details
#api_key_with_prefix(param_name, param_alias = nil) ⇒ Object
Gets API key (with prefix if set).
221 222 223 224 225 226 227 228 229 230 |
# File 'lib/snaptrade/configuration.rb', line 221 def api_key_with_prefix(param_name, param_alias = nil) value = @api_key_store[param_name] value = @api_key_store.fetch(param_alias, value) unless param_alias.nil? return nil if value.nil? if @api_key_prefix[param_name] "#{@api_key_prefix[param_name]}#{value}" else value end end |
#auth_settings ⇒ Object
Returns Auth Settings hash for api client.
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/snaptrade/configuration.rb', line 233 def auth_settings { 'PartnerClientId' => { type: 'api_key', in: 'query', key: 'clientId', value: api_key_with_prefix('PartnerClientId') }, 'PartnerSignature' => { type: 'api_key', in: 'header', key: 'Signature', value: api_key_with_prefix('PartnerSignature') }, 'PartnerTimestamp' => { type: 'api_key', in: 'query', key: 'timestamp', value: api_key_with_prefix('PartnerTimestamp') }, } end |
#base_url(operation = nil) ⇒ Object
Returns base URL for specified operation based on server settings
212 213 214 215 216 217 |
# File 'lib/snaptrade/configuration.rb', line 212 def base_url(operation = nil) index = server_operation_index.fetch(operation, server_index) return "#{scheme}://#{[host, base_path].join('/').gsub(/\/+/, '/')}".sub(/\/+\z/, '') if index == nil server_url(index, server_operation_variables.fetch(operation, server_variables), operation_server_settings[operation]) end |
#client_id=(value) ⇒ Object
33 34 35 |
# File 'lib/snaptrade/configuration.rb', line 33 def client_id=(value) @api_key_store['PartnerClientId'] = value end |
#configure {|_self| ... } ⇒ Object
180 181 182 |
# File 'lib/snaptrade/configuration.rb', line 180 def configure yield(self) if block_given? end |
#configure_middleware(connection) ⇒ Object
Set up middleware on the connection
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/snaptrade/configuration.rb', line 345 def configure_middleware(connection) return if @middlewares.empty? [:request, :response, :use, :insert, :insert_before, :insert_after, :swap].each do |operation| next unless @middlewares.key?(operation) @middlewares[operation].each do |key, args, block| connection.builder.send(operation, key, *args, &block) end end if @middlewares.key?(:delete) @middlewares[:delete].each do |key, _args, _block| connection.builder.delete(key) end end end |
#operation_server_settings ⇒ Object
269 270 271 272 |
# File 'lib/snaptrade/configuration.rb', line 269 def operation_server_settings { } end |
#request(*middleware) ⇒ Object
Adds request middleware to the stack
314 315 316 |
# File 'lib/snaptrade/configuration.rb', line 314 def request(*middleware) set_faraday_middleware(:request, *middleware) end |
#response(*middleware) ⇒ Object
Adds response middleware to the stack
319 320 321 |
# File 'lib/snaptrade/configuration.rb', line 319 def response(*middleware) set_faraday_middleware(:response, *middleware) end |
#server_settings ⇒ Object
Returns an array of Server setting
260 261 262 263 264 265 266 267 |
# File 'lib/snaptrade/configuration.rb', line 260 def server_settings [ { url: "https://api.snaptrade.com/api/v1", description: "SnapTrade Production API", } ] end |
#server_url(index, variables = {}, servers = nil) ⇒ Object
Returns URL based on server settings
278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/snaptrade/configuration.rb', line 278 def server_url(index, variables = {}, servers = nil) servers = server_settings if servers == nil # check array index out of bound if (index < 0 || index >= servers.size) fail ArgumentError, "Invalid index #{index} when selecting the server. Must be less than #{servers.size}" end server = servers[index] url = server[:url] return url unless server.key? :variables # go through variable and assign a value server[:variables].each do |name, variable| if variables.key?(name) if (!server[:variables][name].key?(:enum_values) || server[:variables][name][:enum_values].include?(variables[name])) url.gsub! "{" + name.to_s + "}", variables[name] else fail ArgumentError, "The variable `#{name}` in the server URL has invalid value #{variables[name]}. Must be #{server[:variables][name][:enum_values]}." end else # use default value url.gsub! "{" + name.to_s + "}", server[:variables][name][:default_value] end end url end |
#set_faraday_middleware(operation, key, *args, &block) ⇒ Object
Adds Faraday middleware setting information to the stack
334 335 336 337 338 339 340 341 |
# File 'lib/snaptrade/configuration.rb', line 334 def set_faraday_middleware(operation, key, *args, &block) unless [:request, :response, :use, :insert, :insert_before, :insert_after, :swap, :delete].include?(operation) fail ArgumentError, "Invalid faraday middleware operation #{operation}. Must be" \ " :request, :response, :use, :insert, :insert_before, :insert_after, :swap or :delete." end @middlewares[operation] << [key, args, block] end |
#signature=(value) ⇒ Object
37 38 39 |
# File 'lib/snaptrade/configuration.rb', line 37 def signature=(value) @api_key_store['PartnerSignature'] = value end |
#timestamp=(value) ⇒ Object
41 42 43 |
# File 'lib/snaptrade/configuration.rb', line 41 def (value) @api_key_store['PartnerTimestamp'] = value end |
#use(*middleware) ⇒ Object
Adds middleware to the stack
309 310 311 |
# File 'lib/snaptrade/configuration.rb', line 309 def use(*middleware) set_faraday_middleware(:use, *middleware) end |