Class: SnapTrade::ManualTradeFormWithOptions
- Inherits:
-
Object
- Object
- SnapTrade::ManualTradeFormWithOptions
- Defined in:
- lib/snaptrade/models/manual_trade_form_with_options.rb
Overview
Inputs for placing an order with the brokerage.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Unique identifier for the connected brokerage account.
-
#action ⇒ Object
The action describes the intent or side of a trade.
-
#client_order_id ⇒ Object
Returns the value of attribute client_order_id.
-
#expiry_date ⇒ Object
Timestamp in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format indicating when the order expires.
-
#notional_value ⇒ Object
Returns the value of attribute notional_value.
-
#order_type ⇒ Object
The type of order to place.
-
#price ⇒ Object
The limit price for ‘Limit` and `StopLimit` orders.
-
#stop ⇒ Object
The price at which a stop order is triggered for ‘Stop` and `StopLimit` orders.
-
#symbol ⇒ Object
The security’s trading ticker symbol.
-
#time_in_force ⇒ Object
The Time in Force type for the order.
-
#trading_session ⇒ Object
The trading session for the order.
-
#units ⇒ Object
For Equity orders, this represents the number of shares for the order.
-
#universal_symbol_id ⇒ Object
The universal symbol ID of the security to trade.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ManualTradeFormWithOptions
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ManualTradeFormWithOptions
Initializes the object
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 112 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SnapTrade::ManualTradeFormWithOptions` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SnapTrade::ManualTradeFormWithOptions`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'action') self.action = attributes[:'action'] end if attributes.key?(:'universal_symbol_id') self.universal_symbol_id = attributes[:'universal_symbol_id'] end if attributes.key?(:'symbol') self.symbol = attributes[:'symbol'] end if attributes.key?(:'order_type') self.order_type = attributes[:'order_type'] end if attributes.key?(:'time_in_force') self.time_in_force = attributes[:'time_in_force'] end if attributes.key?(:'trading_session') self.trading_session = attributes[:'trading_session'] else self.trading_session = 'REGULAR' end if attributes.key?(:'expiry_date') self.expiry_date = attributes[:'expiry_date'] end if attributes.key?(:'price') self.price = attributes[:'price'] end if attributes.key?(:'stop') self.stop = attributes[:'stop'] end if attributes.key?(:'units') self.units = attributes[:'units'] end if attributes.key?(:'notional_value') self.notional_value = attributes[:'notional_value'] end if attributes.key?(:'client_order_id') self.client_order_id = attributes[:'client_order_id'] end end |
Instance Attribute Details
#account_id ⇒ Object
Unique identifier for the connected brokerage account. This is the UUID used to reference the account in SnapTrade.
17 18 19 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 17 def account_id @account_id end |
#action ⇒ Object
The action describes the intent or side of a trade. This is either ‘BUY` or `SELL` for Equity symbols or `BUY_TO_OPEN`, `BUY_TO_CLOSE`, `SELL_TO_OPEN` or `SELL_TO_CLOSE` for Options.
20 21 22 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 20 def action @action end |
#client_order_id ⇒ Object
Returns the value of attribute client_order_id.
51 52 53 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 51 def client_order_id @client_order_id end |
#expiry_date ⇒ Object
Timestamp in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format indicating when the order expires. Required when ‘time_in_force` is `GTD`. Include a timezone offset or `Z` for UTC; if no timezone is provided, UTC is assumed. GTD orders are only available on certain brokerages. Visit support.snaptrade.com/brokerages for brokerage support.
38 39 40 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 38 def expiry_date @expiry_date end |
#notional_value ⇒ Object
Returns the value of attribute notional_value.
49 50 51 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 49 def notional_value @notional_value end |
#order_type ⇒ Object
The type of order to place. - For ‘Limit` and `StopLimit` orders, the `price` field is required. - For `Stop` and `StopLimit` orders, the `stop` field is required.
29 30 31 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 29 def order_type @order_type end |
#price ⇒ Object
The limit price for ‘Limit` and `StopLimit` orders.
41 42 43 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 41 def price @price end |
#stop ⇒ Object
The price at which a stop order is triggered for ‘Stop` and `StopLimit` orders.
44 45 46 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 44 def stop @stop end |
#symbol ⇒ Object
The security’s trading ticker symbol. If ‘symbol’ is provided, then ‘universal_symbol_id’ must be ‘null’.
26 27 28 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 26 def symbol @symbol end |
#time_in_force ⇒ Object
The Time in Force type for the order. This field indicates how long the order will remain active before it is executed or expires. Here are the supported values: - ‘Day` - Day. The order is valid only for the trading day on which it is placed. - `GTC` - Good Til Canceled. The order is valid until it is executed or canceled. - `FOK` - Fill Or Kill. The order must be executed in its entirety immediately or be canceled completely. - `IOC` - Immediate Or Cancel. The order must be executed immediately. Any portion of the order that cannot be filled immediately will be canceled. - `GTD` - Good Til Date. The order is valid until `expiry_date`, which is required. Not available for market orders. GTD orders are only available on certain brokerages. Visit support.snaptrade.com/brokerages for brokerage support.
32 33 34 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 32 def time_in_force @time_in_force end |
#trading_session ⇒ Object
The trading session for the order. This field indicates which market session the order will be placed in. This is only available for certain brokerages. Defaults to REGULAR. Here are the supported values: - ‘REGULAR` - Regular trading hours. - `EXTENDED` - Extended trading hours.
35 36 37 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 35 def trading_session @trading_session end |
#units ⇒ Object
For Equity orders, this represents the number of shares for the order. This can be a decimal for fractional orders. Must be ‘null` if `notional_value` is provided. If placing an Option order, this field represents the number of contracts to buy or sell. (e.g., 1 contract = 100 shares).
47 48 49 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 47 def units @units end |
#universal_symbol_id ⇒ Object
The universal symbol ID of the security to trade. Must be ‘null’ if ‘symbol` is provided, otherwise must be provided.
23 24 25 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 23 def universal_symbol_id @universal_symbol_id end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 73 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 54 def self.attribute_map { :'account_id' => :'account_id', :'action' => :'action', :'universal_symbol_id' => :'universal_symbol_id', :'symbol' => :'symbol', :'order_type' => :'order_type', :'time_in_force' => :'time_in_force', :'trading_session' => :'trading_session', :'expiry_date' => :'expiry_date', :'price' => :'price', :'stop' => :'stop', :'units' => :'units', :'notional_value' => :'notional_value', :'client_order_id' => :'client_order_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
248 249 250 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 248 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 97 def self.openapi_nullable Set.new([ :'universal_symbol_id', :'symbol', :'expiry_date', :'price', :'stop', :'units', :'notional_value', :'client_order_id' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 78 def self.openapi_types { :'account_id' => :'String', :'action' => :'ActionStrictWithOptions', :'universal_symbol_id' => :'String', :'symbol' => :'String', :'order_type' => :'OrderTypeStrict', :'time_in_force' => :'ManualTradePlaceTimeInForceStrict', :'trading_session' => :'TradingSession', :'expiry_date' => :'Time', :'price' => :'Float', :'stop' => :'Float', :'units' => :'Float', :'notional_value' => :'ManualTradeFormNotionalValue', :'client_order_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 215 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && action == o.action && universal_symbol_id == o.universal_symbol_id && symbol == o.symbol && order_type == o.order_type && time_in_force == o.time_in_force && trading_session == o.trading_session && expiry_date == o.expiry_date && price == o.price && stop == o.stop && units == o.units && notional_value == o.notional_value && client_order_id == o.client_order_id end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 279 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = SnapTrade.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
350 351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 350 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 255 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
235 236 237 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 235 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
241 242 243 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 241 def hash [account_id, action, universal_symbol_id, symbol, order_type, time_in_force, trading_session, expiry_date, price, stop, units, notional_value, client_order_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 182 def list_invalid_properties invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @action.nil? invalid_properties.push('invalid value for "action", action cannot be nil.') end if @order_type.nil? invalid_properties.push('invalid value for "order_type", order_type cannot be nil.') end if @time_in_force.nil? invalid_properties.push('invalid value for "time_in_force", time_in_force cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
326 327 328 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 326 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 332 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
320 321 322 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 320 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
205 206 207 208 209 210 211 |
# File 'lib/snaptrade/models/manual_trade_form_with_options.rb', line 205 def valid? return false if @account_id.nil? return false if @action.nil? return false if @order_type.nil? return false if @time_in_force.nil? true end |