Class: SnapTrade::ManualTradeReplaceForm

Inherits:
Object
  • Object
show all
Defined in:
lib/snaptrade/models/manual_trade_replace_form.rb

Overview

Inputs for replacing an order with the brokerage.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ManualTradeReplaceForm

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/snaptrade/models/manual_trade_replace_form.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SnapTrade::ManualTradeReplaceForm` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SnapTrade::ManualTradeReplaceForm`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'brokerage_order_id')
    self.brokerage_order_id = attributes[:'brokerage_order_id']
  end

  if attributes.key?(:'action')
    self.action = attributes[:'action']
  end

  if attributes.key?(:'order_type')
    self.order_type = attributes[:'order_type']
  end

  if attributes.key?(:'time_in_force')
    self.time_in_force = attributes[:'time_in_force']
  end

  if attributes.key?(:'price')
    self.price = attributes[:'price']
  end

  if attributes.key?(:'symbol')
    self.symbol = attributes[:'symbol']
  end

  if attributes.key?(:'stop')
    self.stop = attributes[:'stop']
  end

  if attributes.key?(:'units')
    self.units = attributes[:'units']
  end
end

Instance Attribute Details

#actionObject

The action describes the intent or side of a trade. This is either ‘BUY` or `SELL`.



20
21
22
# File 'lib/snaptrade/models/manual_trade_replace_form.rb', line 20

def action
  @action
end

#brokerage_order_idObject

Order ID returned by brokerage. This is the unique identifier for the order in the brokerage system.



17
18
19
# File 'lib/snaptrade/models/manual_trade_replace_form.rb', line 17

def brokerage_order_id
  @brokerage_order_id
end

#order_typeObject

The type of order to place. - For ‘Limit` and `StopLimit` orders, the `price` field is required. - For `Stop` and `StopLimit` orders, the `stop` field is required.



23
24
25
# File 'lib/snaptrade/models/manual_trade_replace_form.rb', line 23

def order_type
  @order_type
end

#priceObject

The limit price for ‘Limit` and `StopLimit` orders.



29
30
31
# File 'lib/snaptrade/models/manual_trade_replace_form.rb', line 29

def price
  @price
end

#stopObject

The price at which a stop order is triggered for ‘Stop` and `StopLimit` orders.



35
36
37
# File 'lib/snaptrade/models/manual_trade_replace_form.rb', line 35

def stop
  @stop
end

#symbolObject

The security’s trading ticker symbol



32
33
34
# File 'lib/snaptrade/models/manual_trade_replace_form.rb', line 32

def symbol
  @symbol
end

#time_in_forceObject

The Time in Force type for the order. This field indicates how long the order will remain active before it is executed or expires. Here are the supported values: - ‘Day` - Day. The order is valid only for the trading day on which it is placed. - `GTC` - Good Til Canceled. The order is valid until it is executed or canceled. - `FOK` - Fill Or Kill. The order must be executed in its entirety immediately or be canceled completely. - `IOC` - Immediate Or Cancel. The order must be executed immediately. Any portion of the order that cannot be filled immediately will be canceled.



26
27
28
# File 'lib/snaptrade/models/manual_trade_replace_form.rb', line 26

def time_in_force
  @time_in_force
end

#unitsObject

Returns the value of attribute units.



37
38
39
# File 'lib/snaptrade/models/manual_trade_replace_form.rb', line 37

def units
  @units
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/snaptrade/models/manual_trade_replace_form.rb', line 54

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/snaptrade/models/manual_trade_replace_form.rb', line 40

def self.attribute_map
  {
    :'brokerage_order_id' => :'brokerage_order_id',
    :'action' => :'action',
    :'order_type' => :'order_type',
    :'time_in_force' => :'time_in_force',
    :'price' => :'price',
    :'symbol' => :'symbol',
    :'stop' => :'stop',
    :'units' => :'units'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



192
193
194
# File 'lib/snaptrade/models/manual_trade_replace_form.rb', line 192

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



73
74
75
76
77
78
79
# File 'lib/snaptrade/models/manual_trade_replace_form.rb', line 73

def self.openapi_nullable
  Set.new([
    :'price',
    :'stop',
    :'units'
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/snaptrade/models/manual_trade_replace_form.rb', line 59

def self.openapi_types
  {
    :'brokerage_order_id' => :'String',
    :'action' => :'ActionStrict',
    :'order_type' => :'OrderTypeStrict',
    :'time_in_force' => :'TimeInForceStrict',
    :'price' => :'Float',
    :'symbol' => :'String',
    :'stop' => :'Float',
    :'units' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/snaptrade/models/manual_trade_replace_form.rb', line 164

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      brokerage_order_id == o.brokerage_order_id &&
      action == o.action &&
      order_type == o.order_type &&
      time_in_force == o.time_in_force &&
      price == o.price &&
      symbol == o.symbol &&
      stop == o.stop &&
      units == o.units
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/snaptrade/models/manual_trade_replace_form.rb', line 223

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = SnapTrade.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/snaptrade/models/manual_trade_replace_form.rb', line 294

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/snaptrade/models/manual_trade_replace_form.rb', line 199

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


179
180
181
# File 'lib/snaptrade/models/manual_trade_replace_form.rb', line 179

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



185
186
187
# File 'lib/snaptrade/models/manual_trade_replace_form.rb', line 185

def hash
  [brokerage_order_id, action, order_type, time_in_force, price, symbol, stop, units].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/snaptrade/models/manual_trade_replace_form.rb', line 131

def list_invalid_properties
  invalid_properties = Array.new
  if @brokerage_order_id.nil?
    invalid_properties.push('invalid value for "brokerage_order_id", brokerage_order_id cannot be nil.')
  end

  if @action.nil?
    invalid_properties.push('invalid value for "action", action cannot be nil.')
  end

  if @order_type.nil?
    invalid_properties.push('invalid value for "order_type", order_type cannot be nil.')
  end

  if @time_in_force.nil?
    invalid_properties.push('invalid value for "time_in_force", time_in_force cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



270
271
272
# File 'lib/snaptrade/models/manual_trade_replace_form.rb', line 270

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/snaptrade/models/manual_trade_replace_form.rb', line 276

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



264
265
266
# File 'lib/snaptrade/models/manual_trade_replace_form.rb', line 264

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



154
155
156
157
158
159
160
# File 'lib/snaptrade/models/manual_trade_replace_form.rb', line 154

def valid?
  return false if @brokerage_order_id.nil?
  return false if @action.nil?
  return false if @order_type.nil?
  return false if @time_in_force.nil?
  true
end