Class: SnapTrade::OrderUpdatedResponseOrder
- Inherits:
-
Object
- Object
- SnapTrade::OrderUpdatedResponseOrder
- Defined in:
- lib/snaptrade/models/order_updated_response_order.rb
Instance Attribute Summary collapse
-
#action ⇒ Object
The action describes the intent or side of a trade.
-
#brokerage_group_order_id ⇒ Object
The brokerage-assigned identifier that links all orders within a complex order (OCO, OTO, OTOCO) together.
-
#brokerage_order_id ⇒ Object
Order ID returned by brokerage.
-
#canceled_quantity ⇒ Object
The number of shares or contracts that have been canceled.
-
#child_brokerage_order_ids ⇒ Object
Returns the value of attribute child_brokerage_order_ids.
-
#execution_price ⇒ Object
The price at which the order was executed.
-
#expiry_date ⇒ Object
The time the order expires.
-
#filled_quantity ⇒ Object
The number of shares or contracts that have been filled.
-
#limit_price ⇒ Object
The limit price is maximum price one is willing to pay for a buy order or the minimum price one is willing to accept for a sell order.
-
#open_quantity ⇒ Object
The number of shares or contracts that are still open (waiting for execution).
-
#option_symbol ⇒ Object
Returns the value of attribute option_symbol.
-
#order_role ⇒ Object
The role of this order within a complex order group (OCO, OTO, OTOCO).
-
#order_type ⇒ Object
The type of order placed.
-
#quote_currency ⇒ Object
Returns the value of attribute quote_currency.
-
#quote_universal_symbol ⇒ Object
Returns the value of attribute quote_universal_symbol.
-
#status ⇒ Object
Indicates the status of an order.
-
#stop_price ⇒ Object
The stop price is the price at which a stop order is triggered.
-
#symbol ⇒ Object
A unique ID for the security within SnapTrade, scoped to the brokerage account that the security belongs to.
-
#time_executed ⇒ Object
The time the order was executed in the brokerage system.
-
#time_in_force ⇒ Object
The Time in Force type for the order.
-
#time_placed ⇒ Object
The time the order was placed.
-
#time_updated ⇒ Object
The time the order was last updated in the brokerage system.
-
#total_quantity ⇒ Object
The total number of shares or contracts of the order.
-
#trailing_stop ⇒ Object
Returns the value of attribute trailing_stop.
-
#universal_symbol ⇒ Object
Returns the value of attribute universal_symbol.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OrderUpdatedResponseOrder
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ OrderUpdatedResponseOrder
Initializes the object
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 181 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SnapTrade::OrderUpdatedResponseOrder` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SnapTrade::OrderUpdatedResponseOrder`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'brokerage_order_id') self.brokerage_order_id = attributes[:'brokerage_order_id'] end if attributes.key?(:'brokerage_group_order_id') self.brokerage_group_order_id = attributes[:'brokerage_group_order_id'] end if attributes.key?(:'order_role') self.order_role = attributes[:'order_role'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'universal_symbol') self.universal_symbol = attributes[:'universal_symbol'] end if attributes.key?(:'option_symbol') self.option_symbol = attributes[:'option_symbol'] end if attributes.key?(:'quote_universal_symbol') self.quote_universal_symbol = attributes[:'quote_universal_symbol'] end if attributes.key?(:'quote_currency') self.quote_currency = attributes[:'quote_currency'] end if attributes.key?(:'action') self.action = attributes[:'action'] end if attributes.key?(:'total_quantity') self.total_quantity = attributes[:'total_quantity'] end if attributes.key?(:'open_quantity') self.open_quantity = attributes[:'open_quantity'] end if attributes.key?(:'canceled_quantity') self.canceled_quantity = attributes[:'canceled_quantity'] end if attributes.key?(:'filled_quantity') self.filled_quantity = attributes[:'filled_quantity'] end if attributes.key?(:'execution_price') self.execution_price = attributes[:'execution_price'] end if attributes.key?(:'limit_price') self.limit_price = attributes[:'limit_price'] end if attributes.key?(:'stop_price') self.stop_price = attributes[:'stop_price'] end if attributes.key?(:'trailing_stop') self.trailing_stop = attributes[:'trailing_stop'] end if attributes.key?(:'order_type') self.order_type = attributes[:'order_type'] end if attributes.key?(:'time_in_force') self.time_in_force = attributes[:'time_in_force'] end if attributes.key?(:'time_placed') self.time_placed = attributes[:'time_placed'] end if attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] end if attributes.key?(:'time_executed') self.time_executed = attributes[:'time_executed'] end if attributes.key?(:'expiry_date') self.expiry_date = attributes[:'expiry_date'] end if attributes.key?(:'symbol') self.symbol = attributes[:'symbol'] end if attributes.key?(:'child_brokerage_order_ids') self.child_brokerage_order_ids = attributes[:'child_brokerage_order_ids'] end end |
Instance Attribute Details
#action ⇒ Object
The action describes the intent or side of a trade. This is usually ‘BUY` or `SELL` but can include other potential values like the following depending on the specific brokerage. - BUY - SELL - BUY_COVER - SELL_SHORT - BUY_OPEN - BUY_CLOSE - SELL_OPEN - SELL_CLOSE
36 37 38 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 36 def action @action end |
#brokerage_group_order_id ⇒ Object
The brokerage-assigned identifier that links all orders within a complex order (OCO, OTO, OTOCO) together. Null for non-complex orders or when the brokerage does not return a group identifier.
19 20 21 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 19 def brokerage_group_order_id @brokerage_group_order_id end |
#brokerage_order_id ⇒ Object
Order ID returned by brokerage. This is the unique identifier for the order in the brokerage system.
16 17 18 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 16 def brokerage_order_id @brokerage_order_id end |
#canceled_quantity ⇒ Object
The number of shares or contracts that have been canceled. Can be a decimal number for fractional shares.
45 46 47 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 45 def canceled_quantity @canceled_quantity end |
#child_brokerage_order_ids ⇒ Object
Returns the value of attribute child_brokerage_order_ids.
82 83 84 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 82 def child_brokerage_order_ids @child_brokerage_order_ids end |
#execution_price ⇒ Object
The price at which the order was executed. For option orders, this represents the price per share.
51 52 53 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 51 def execution_price @execution_price end |
#expiry_date ⇒ Object
The time the order expires. This value is not always available from the brokerage.
77 78 79 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 77 def expiry_date @expiry_date end |
#filled_quantity ⇒ Object
The number of shares or contracts that have been filled. Can be a decimal number for fractional shares.
48 49 50 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 48 def filled_quantity @filled_quantity end |
#limit_price ⇒ Object
The limit price is maximum price one is willing to pay for a buy order or the minimum price one is willing to accept for a sell order. Should only apply to ‘Limit` and `StopLimit` orders. For option orders, this represents the price per share.
54 55 56 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 54 def limit_price @limit_price end |
#open_quantity ⇒ Object
The number of shares or contracts that are still open (waiting for execution). Can be a decimal number for fractional shares.
42 43 44 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 42 def open_quantity @open_quantity end |
#option_symbol ⇒ Object
Returns the value of attribute option_symbol.
29 30 31 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 29 def option_symbol @option_symbol end |
#order_role ⇒ Object
The role of this order within a complex order group (OCO, OTO, OTOCO). Null for non-complex orders.
22 23 24 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 22 def order_role @order_role end |
#order_type ⇒ Object
The type of order placed. The most common values are ‘Market`, `Limit`, `Stop`, and `StopLimit`. We try our best to map brokerage order types to these values. When mapping fails, we will return the brokerage’s order type value.
62 63 64 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 62 def order_type @order_type end |
#quote_currency ⇒ Object
Returns the value of attribute quote_currency.
33 34 35 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 33 def quote_currency @quote_currency end |
#quote_universal_symbol ⇒ Object
Returns the value of attribute quote_universal_symbol.
31 32 33 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 31 def quote_universal_symbol @quote_universal_symbol end |
#status ⇒ Object
Indicates the status of an order. SnapTrade does a best effort to map brokerage statuses to statuses in this enum. Possible values include: - NONE - PENDING - ACCEPTED - FAILED - REJECTED - CANCELED - PARTIAL_CANCELED - CANCEL_PENDING - EXECUTED - PARTIAL - REPLACE_PENDING - REPLACED - EXPIRED - QUEUED - TRIGGERED - ACTIVATED
25 26 27 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 25 def status @status end |
#stop_price ⇒ Object
The stop price is the price at which a stop order is triggered. Should only apply to ‘Stop` and `StopLimit` orders. For option orders, this represents the price per share.
57 58 59 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 57 def stop_price @stop_price end |
#symbol ⇒ Object
A unique ID for the security within SnapTrade, scoped to the brokerage account that the security belongs to. This is a legacy field and should not be used. Do not rely on this being a stable ID as it can change.
80 81 82 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 80 def symbol @symbol end |
#time_executed ⇒ Object
The time the order was executed in the brokerage system. This value is not always available from the brokerage.
74 75 76 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 74 def time_executed @time_executed end |
#time_in_force ⇒ Object
The Time in Force type for the order. This field indicates how long the order will remain active before it is executed or expires. We try our best to map brokerage time in force values to the following. When mapping fails, we will return the brokerage’s time in force value. - ‘Day` - Day. The order is valid only for the trading day on which it is placed. - `GTC` - Good Til Canceled. The order is valid until it is executed or canceled. - `FOK` - Fill Or Kill. The order must be executed in its entirety immediately or be canceled completely. - `IOC` - Immediate Or Cancel. The order must be executed immediately. Any portion of the order that cannot be filled immediately will be canceled. - `GTD` - Good Til Date. The order is valid until the specified date. - `MOO` - Market On Open. The order is to be executed at the day’s opening price. - ‘EHP` - Extended Hours P.M. The order is to be placed during extended hour trading, after markets close.
65 66 67 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 65 def time_in_force @time_in_force end |
#time_placed ⇒ Object
The time the order was placed. This is the time the order was submitted to the brokerage.
68 69 70 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 68 def time_placed @time_placed end |
#time_updated ⇒ Object
The time the order was last updated in the brokerage system. This value is not always available from the brokerage.
71 72 73 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 71 def time_updated @time_updated end |
#total_quantity ⇒ Object
The total number of shares or contracts of the order. This should be the sum of the filled, canceled, and open quantities. Can be a decimal number for fractional shares.
39 40 41 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 39 def total_quantity @total_quantity end |
#trailing_stop ⇒ Object
Returns the value of attribute trailing_stop.
59 60 61 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 59 def trailing_stop @trailing_stop end |
#universal_symbol ⇒ Object
Returns the value of attribute universal_symbol.
27 28 29 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 27 def universal_symbol @universal_symbol end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
116 117 118 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 116 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 85 def self.attribute_map { :'brokerage_order_id' => :'brokerage_order_id', :'brokerage_group_order_id' => :'brokerage_group_order_id', :'order_role' => :'order_role', :'status' => :'status', :'universal_symbol' => :'universal_symbol', :'option_symbol' => :'option_symbol', :'quote_universal_symbol' => :'quote_universal_symbol', :'quote_currency' => :'quote_currency', :'action' => :'action', :'total_quantity' => :'total_quantity', :'open_quantity' => :'open_quantity', :'canceled_quantity' => :'canceled_quantity', :'filled_quantity' => :'filled_quantity', :'execution_price' => :'execution_price', :'limit_price' => :'limit_price', :'stop_price' => :'stop_price', :'trailing_stop' => :'trailing_stop', :'order_type' => :'order_type', :'time_in_force' => :'time_in_force', :'time_placed' => :'time_placed', :'time_updated' => :'time_updated', :'time_executed' => :'time_executed', :'expiry_date' => :'expiry_date', :'symbol' => :'symbol', :'child_brokerage_order_ids' => :'child_brokerage_order_ids' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
355 356 357 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 355 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
173 174 175 176 177 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 173 def self.openapi_all_of [ :'AccountOrderRecord' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 152 def self.openapi_nullable Set.new([ :'brokerage_group_order_id', :'order_role', :'total_quantity', :'open_quantity', :'canceled_quantity', :'filled_quantity', :'execution_price', :'limit_price', :'stop_price', :'trailing_stop', :'order_type', :'time_updated', :'time_executed', :'expiry_date', :'child_brokerage_order_ids' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 121 def self.openapi_types { :'brokerage_order_id' => :'String', :'brokerage_group_order_id' => :'String', :'order_role' => :'OrderRole', :'status' => :'AccountOrderRecordStatus', :'universal_symbol' => :'AccountOrderRecordUniversalSymbol', :'option_symbol' => :'AccountOrderRecordOptionSymbol', :'quote_universal_symbol' => :'AccountOrderRecordQuoteUniversalSymbol', :'quote_currency' => :'AccountOrderRecordQuoteCurrency', :'action' => :'String', :'total_quantity' => :'String', :'open_quantity' => :'String', :'canceled_quantity' => :'String', :'filled_quantity' => :'String', :'execution_price' => :'Float', :'limit_price' => :'Float', :'stop_price' => :'Float', :'trailing_stop' => :'AccountOrderRecordTrailingStop', :'order_type' => :'String', :'time_in_force' => :'String', :'time_placed' => :'Time', :'time_updated' => :'Time', :'time_executed' => :'Time', :'expiry_date' => :'Time', :'symbol' => :'String', :'child_brokerage_order_ids' => :'AccountOrderRecordChildBrokerageOrderIds' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 310 def ==(o) return true if self.equal?(o) self.class == o.class && brokerage_order_id == o.brokerage_order_id && brokerage_group_order_id == o.brokerage_group_order_id && order_role == o.order_role && status == o.status && universal_symbol == o.universal_symbol && option_symbol == o.option_symbol && quote_universal_symbol == o.quote_universal_symbol && quote_currency == o.quote_currency && action == o.action && total_quantity == o.total_quantity && open_quantity == o.open_quantity && canceled_quantity == o.canceled_quantity && filled_quantity == o.filled_quantity && execution_price == o.execution_price && limit_price == o.limit_price && stop_price == o.stop_price && trailing_stop == o.trailing_stop && order_type == o.order_type && time_in_force == o.time_in_force && time_placed == o.time_placed && time_updated == o.time_updated && time_executed == o.time_executed && expiry_date == o.expiry_date && symbol == o.symbol && child_brokerage_order_ids == o.child_brokerage_order_ids end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 386 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = SnapTrade.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
457 458 459 460 461 462 463 464 465 466 467 468 469 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 457 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 362 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
342 343 344 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 342 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
348 349 350 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 348 def hash [brokerage_order_id, brokerage_group_order_id, order_role, status, universal_symbol, option_symbol, quote_universal_symbol, quote_currency, action, total_quantity, open_quantity, canceled_quantity, filled_quantity, execution_price, limit_price, stop_price, trailing_stop, order_type, time_in_force, time_placed, time_updated, time_executed, expiry_date, symbol, child_brokerage_order_ids].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
297 298 299 300 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 297 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
433 434 435 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 433 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
439 440 441 442 443 444 445 446 447 448 449 450 451 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 439 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
427 428 429 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 427 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
304 305 306 |
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 304 def valid? true end |