Class: SnapTrade::SimpleOrderForm
- Inherits:
-
Object
- Object
- SnapTrade::SimpleOrderForm
- Defined in:
- lib/snaptrade/models/simple_order_form.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount of the base currency to buy or sell.
-
#expiration_date ⇒ Object
The expiration date of the order.
-
#instrument ⇒ Object
Returns the value of attribute instrument.
-
#limit_price ⇒ Object
The limit price.
-
#post_only ⇒ Object
Valid and required only for order type LIMIT.
-
#side ⇒ Object
The action describes the intent or side of a trade.
-
#stop_price ⇒ Object
The stop price.
-
#time_in_force ⇒ Object
The Time in Force type for the order.
-
#type ⇒ Object
The type of order to place.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SimpleOrderForm
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ SimpleOrderForm
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SnapTrade::SimpleOrderForm` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SnapTrade::SimpleOrderForm`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'instrument') self.instrument = attributes[:'instrument'] end if attributes.key?(:'side') self.side = attributes[:'side'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'time_in_force') self.time_in_force = attributes[:'time_in_force'] end if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'limit_price') self.limit_price = attributes[:'limit_price'] end if attributes.key?(:'stop_price') self.stop_price = attributes[:'stop_price'] end if attributes.key?(:'post_only') self.post_only = attributes[:'post_only'] end if attributes.key?(:'expiration_date') self.expiration_date = attributes[:'expiration_date'] end end |
Instance Attribute Details
#amount ⇒ Object
The amount of the base currency to buy or sell.
27 28 29 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 27 def amount @amount end |
#expiration_date ⇒ Object
The expiration date of the order. Required if the time_in_force is GTD.
39 40 41 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 39 def expiration_date @expiration_date end |
#instrument ⇒ Object
Returns the value of attribute instrument.
15 16 17 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 15 def instrument @instrument end |
#limit_price ⇒ Object
The limit price. Required if the order type is LIMIT, STOP_LOSS_LIMIT or TAKE_PROFIT_LIMIT.
30 31 32 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 30 def limit_price @limit_price end |
#post_only ⇒ Object
Valid and required only for order type LIMIT. If true orders that would be filled immediately are rejected to avoid incurring TAKER fees.
36 37 38 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 36 def post_only @post_only end |
#side ⇒ Object
The action describes the intent or side of a trade. This is either ‘BUY` or `SELL`.
18 19 20 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 18 def side @side end |
#stop_price ⇒ Object
The stop price. Required if the order type is STOP_LOSS_MARKET, STOP_LOSS_LIMIT, TAKE_PROFIT_MARKET or TAKE_PROFIT_LIMIT.
33 34 35 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 33 def stop_price @stop_price end |
#time_in_force ⇒ Object
The Time in Force type for the order. This field indicates how long the order will remain active before it is executed or expires. - ‘GTC` - Good Til Canceled. The order is valid until it is executed or canceled. - `FOK` - Fill Or Kill. The order must be executed in its entirety immediately or be canceled completely. - `IOC` - Immediate Or Cancel. The order must be executed immediately. Any portion of the order that cannot be filled immediately will be canceled. - `GTD` - Good Til Date. The order is valid until the specified date.
24 25 26 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 24 def time_in_force @time_in_force end |
#type ⇒ Object
The type of order to place.
21 22 23 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 21 def type @type end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
57 58 59 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 57 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 42 def self.attribute_map { :'instrument' => :'instrument', :'side' => :'side', :'type' => :'type', :'time_in_force' => :'time_in_force', :'amount' => :'amount', :'limit_price' => :'limit_price', :'stop_price' => :'stop_price', :'post_only' => :'post_only', :'expiration_date' => :'expiration_date' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
203 204 205 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 203 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 77 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 62 def self.openapi_types { :'instrument' => :'TradingInstrument', :'side' => :'ActionStrict', :'type' => :'SimpleOrderFormType', :'time_in_force' => :'SimpleOrderFormTimeInForce', :'amount' => :'Float', :'limit_price' => :'Float', :'stop_price' => :'Float', :'post_only' => :'Boolean', :'expiration_date' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 174 def ==(o) return true if self.equal?(o) self.class == o.class && instrument == o.instrument && side == o.side && type == o.type && time_in_force == o.time_in_force && amount == o.amount && limit_price == o.limit_price && stop_price == o.stop_price && post_only == o.post_only && expiration_date == o.expiration_date end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 234 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = SnapTrade.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 305 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 210 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
190 191 192 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 190 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
196 197 198 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 196 def hash [instrument, side, type, time_in_force, amount, limit_price, stop_price, post_only, expiration_date].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 136 def list_invalid_properties invalid_properties = Array.new if @instrument.nil? invalid_properties.push('invalid value for "instrument", instrument cannot be nil.') end if @side.nil? invalid_properties.push('invalid value for "side", side cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @time_in_force.nil? invalid_properties.push('invalid value for "time_in_force", time_in_force cannot be nil.') end if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
281 282 283 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 281 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 287 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
275 276 277 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 275 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
163 164 165 166 167 168 169 170 |
# File 'lib/snaptrade/models/simple_order_form.rb', line 163 def valid? return false if @instrument.nil? return false if @side.nil? return false if @type.nil? return false if @time_in_force.nil? return false if @amount.nil? true end |