Class: SnapTrade::AccountInformationApi
- Inherits:
-
Object
- Object
- SnapTrade::AccountInformationApi
- Defined in:
- lib/snaptrade/api/account_information_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_account_activities(account_id:, user_id:, user_secret:, start_date: SENTINEL, end_date: SENTINEL, offset: SENTINEL, limit: SENTINEL, type: SENTINEL, extra: {}) ⇒ Object
List account activities.
-
#get_account_activities_with_http_info(account_id:, user_id:, user_secret:, start_date: SENTINEL, end_date: SENTINEL, offset: SENTINEL, limit: SENTINEL, type: SENTINEL, extra: {}) ⇒ Object
List account activities.
-
#get_account_balance_history(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
List historical account total value.
-
#get_account_balance_history_with_http_info(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
List historical account total value.
-
#get_all_account_positions(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
List all account positions.
-
#get_all_account_positions_with_http_info(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
List all account positions.
-
#get_all_user_holdings(user_id:, user_secret:, brokerage_authorizations: SENTINEL, extra: {}) ⇒ Object
List all accounts for the user, plus balances, positions, and orders for each account.
-
#get_all_user_holdings_with_http_info(user_id:, user_secret:, brokerage_authorizations: SENTINEL, extra: {}) ⇒ Object
List all accounts for the user, plus balances, positions, and orders for each account.
-
#get_user_account_balance(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
List account balances.
-
#get_user_account_balance_with_http_info(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
List account balances.
-
#get_user_account_details(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
Get account detail.
-
#get_user_account_details_with_http_info(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
Get account detail.
-
#get_user_account_order_detail(brokerage_order_id:, account_id:, user_id:, user_secret:, extra: {}) ⇒ Object
Get account order detail.
-
#get_user_account_order_detail_with_http_info(brokerage_order_id:, account_id:, user_id:, user_secret:, extra: {}) ⇒ Object
Get account order detail.
-
#get_user_account_orders(user_id:, user_secret:, account_id:, state: SENTINEL, days: SENTINEL, extra: {}) ⇒ Object
List account orders.
-
#get_user_account_orders_with_http_info(user_id:, user_secret:, account_id:, state: SENTINEL, days: SENTINEL, extra: {}) ⇒ Object
List account orders.
-
#get_user_account_positions(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
List account positions.
-
#get_user_account_positions_with_http_info(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
List account positions.
-
#get_user_account_recent_orders(user_id:, user_secret:, account_id:, only_executed: SENTINEL, extra: {}) ⇒ Object
List account recent orders (last 24 hours only).
-
#get_user_account_recent_orders_with_http_info(user_id:, user_secret:, account_id:, only_executed: SENTINEL, extra: {}) ⇒ Object
List account recent orders (last 24 hours only).
-
#get_user_account_return_rates(user_id:, user_secret:, account_id:, timeframes: SENTINEL, extra: {}) ⇒ Object
List account rate of returns.
-
#get_user_account_return_rates_with_http_info(user_id:, user_secret:, account_id:, timeframes: SENTINEL, extra: {}) ⇒ Object
List account rate of returns.
-
#get_user_holdings(account_id:, user_id:, user_secret:, extra: {}) ⇒ Object
List account holdings.
-
#get_user_holdings_with_http_info(account_id:, user_id:, user_secret:, extra: {}) ⇒ Object
List account holdings.
-
#initialize(api_client = ApiClient.default) ⇒ AccountInformationApi
constructor
A new instance of AccountInformationApi.
-
#list_user_accounts(user_id:, user_secret:, extra: {}) ⇒ Object
List accounts.
-
#list_user_accounts_with_http_info(user_id:, user_secret:, extra: {}) ⇒ Object
List accounts.
-
#update_user_account(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
Update details of an investment account.
-
#update_user_account_with_http_info(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
Update details of an investment account.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ AccountInformationApi
Returns a new instance of AccountInformationApi.
16 17 18 |
# File 'lib/snaptrade/api/account_information_api.rb', line 16 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
14 15 16 |
# File 'lib/snaptrade/api/account_information_api.rb', line 14 def api_client @api_client end |
Instance Method Details
#get_account_activities(account_id:, user_id:, user_secret:, start_date: SENTINEL, end_date: SENTINEL, offset: SENTINEL, limit: SENTINEL, type: SENTINEL, extra: {}) ⇒ Object
List account activities
Returns all historical transactions for the specified account.
This endpoint is paginated with a default page size of 1000. The endpoint will return a maximum of 1000 transactions per request. See the query parameters for pagination options.
Transaction are returned in reverse chronological order, using the ‘trade_date` field.
The data returned here is always cached and refreshed once a day.
If the connection has become disabled, it can no longer access the latest data from the brokerage, but will continue to return the last available cached state. Please see [this guide](/docs/fix-broken-connections) on how to fix a disabled connection.
41 42 43 44 45 46 47 48 49 |
# File 'lib/snaptrade/api/account_information_api.rb', line 41 def get_account_activities(account_id:, user_id:, user_secret:, start_date: SENTINEL, end_date: SENTINEL, offset: SENTINEL, limit: SENTINEL, type: SENTINEL, extra: {}) extra[:start_date] = start_date if start_date != SENTINEL extra[:end_date] = end_date if end_date != SENTINEL extra[:offset] = offset if offset != SENTINEL extra[:limit] = limit if limit != SENTINEL extra[:type] = type if type != SENTINEL data, _status_code, _headers = get_account_activities_with_http_info_impl(account_id, user_id, user_secret, extra) data end |
#get_account_activities_with_http_info(account_id:, user_id:, user_secret:, start_date: SENTINEL, end_date: SENTINEL, offset: SENTINEL, limit: SENTINEL, type: SENTINEL, extra: {}) ⇒ Object
List account activities
Returns all historical transactions for the specified account.
This endpoint is paginated with a default page size of 1000. The endpoint will return a maximum of 1000 transactions per request. See the query parameters for pagination options.
Transaction are returned in reverse chronological order, using the ‘trade_date` field.
The data returned here is always cached and refreshed once a day.
If the connection has become disabled, it can no longer access the latest data from the brokerage, but will continue to return the last available cached state. Please see [this guide](/docs/fix-broken-connections) on how to fix a disabled connection.
72 73 74 75 76 77 78 79 |
# File 'lib/snaptrade/api/account_information_api.rb', line 72 def get_account_activities_with_http_info(account_id:, user_id:, user_secret:, start_date: SENTINEL, end_date: SENTINEL, offset: SENTINEL, limit: SENTINEL, type: SENTINEL, extra: {}) extra[:start_date] = start_date if start_date != SENTINEL extra[:end_date] = end_date if end_date != SENTINEL extra[:offset] = offset if offset != SENTINEL extra[:limit] = limit if limit != SENTINEL extra[:type] = type if type != SENTINEL get_account_activities_with_http_info_impl(account_id, user_id, user_secret, extra) end |
#get_account_balance_history(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
List historical account total value
An experimental endpoint that returns estimated historical total account value for the specified account. Total account value is the sum of the market value of all positions and cash in the account at a given time. This endpoint is experimental, disabled by default, and has a maximum lookback of 1 year.
190 191 192 193 |
# File 'lib/snaptrade/api/account_information_api.rb', line 190 def get_account_balance_history(user_id:, user_secret:, account_id:, extra: {}) data, _status_code, _headers = get_account_balance_history_with_http_info_impl(user_id, user_secret, account_id, extra) data end |
#get_account_balance_history_with_http_info(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
List historical account total value
An experimental endpoint that returns estimated historical total account value for the specified account. Total account value is the sum of the market value of all positions and cash in the account at a given time. This endpoint is experimental, disabled by default, and has a maximum lookback of 1 year.
203 204 205 |
# File 'lib/snaptrade/api/account_information_api.rb', line 203 def get_account_balance_history_with_http_info(user_id:, user_secret:, account_id:, extra: {}) get_account_balance_history_with_http_info_impl(user_id, user_secret, account_id, extra) end |
#get_all_account_positions(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
List all account positions
Returns a list of all positions in the specified account.
The ‘results` list can contain multiple instrument types in the same response, including stocks, ADRs, ETFs, mutual funds, closed-end funds, crypto, futures, and option positions. Use the `instrument.kind` discriminator to determine the schema for each position’s ‘instrument`.
Stock positions may also include ‘cash_equivalent`, and may include `tax_lots` when tax lot data is enabled for the account.
If the connection has become disabled, it can no longer access the latest data from the brokerage, but will continue to return the last available cached state. Please see [this guide](/docs/fix-broken-connections) on how to fix a disabled connection.
299 300 301 302 |
# File 'lib/snaptrade/api/account_information_api.rb', line 299 def get_all_account_positions(user_id:, user_secret:, account_id:, extra: {}) data, _status_code, _headers = get_all_account_positions_with_http_info_impl(user_id, user_secret, account_id, extra) data end |
#get_all_account_positions_with_http_info(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
List all account positions
Returns a list of all positions in the specified account.
The ‘results` list can contain multiple instrument types in the same response, including stocks, ADRs, ETFs, mutual funds, closed-end funds, crypto, futures, and option positions. Use the `instrument.kind` discriminator to determine the schema for each position’s ‘instrument`.
Stock positions may also include ‘cash_equivalent`, and may include `tax_lots` when tax lot data is enabled for the account.
If the connection has become disabled, it can no longer access the latest data from the brokerage, but will continue to return the last available cached state. Please see [this guide](/docs/fix-broken-connections) on how to fix a disabled connection.
318 319 320 |
# File 'lib/snaptrade/api/account_information_api.rb', line 318 def get_all_account_positions_with_http_info(user_id:, user_secret:, account_id:, extra: {}) get_all_account_positions_with_http_info_impl(user_id, user_secret, account_id, extra) end |
#get_all_user_holdings(user_id:, user_secret:, brokerage_authorizations: SENTINEL, extra: {}) ⇒ Object
List all accounts for the user, plus balances, positions, and orders for each account.
**Deprecated, please use the account-specific holdings endpoint instead.**
List all accounts for the user, plus balances, positions, and orders for each account.
Note: This endpoint will return HTTP 410 Gone for all customers that sign up after April 25, 2026.
413 414 415 416 417 |
# File 'lib/snaptrade/api/account_information_api.rb', line 413 def get_all_user_holdings(user_id:, user_secret:, brokerage_authorizations: SENTINEL, extra: {}) extra[:brokerage_authorizations] = if != SENTINEL data, _status_code, _headers = get_all_user_holdings_with_http_info_impl(user_id, user_secret, extra) data end |
#get_all_user_holdings_with_http_info(user_id:, user_secret:, brokerage_authorizations: SENTINEL, extra: {}) ⇒ Object
List all accounts for the user, plus balances, positions, and orders for each account.
**Deprecated, please use the account-specific holdings endpoint instead.**
List all accounts for the user, plus balances, positions, and orders for each account.
Note: This endpoint will return HTTP 410 Gone for all customers that sign up after April 25, 2026.
432 433 434 435 |
# File 'lib/snaptrade/api/account_information_api.rb', line 432 def get_all_user_holdings_with_http_info(user_id:, user_secret:, brokerage_authorizations: SENTINEL, extra: {}) extra[:brokerage_authorizations] = if != SENTINEL get_all_user_holdings_with_http_info_impl(user_id, user_secret, extra) end |
#get_user_account_balance(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
List account balances
Returns a list of balances for the account. Each element of the list has a distinct currency. Some brokerages like Questrade [allows holding multiple currencies in the same account](www.questrade.com/learning/questrade-basics/balances-and-reports/understanding-your-account-balances).
Check your API key on the [Customer Dashboard billing page](dashboard.snaptrade.com/settings/billing) to see if you have real-time data access:
- If you do, this endpoint returns real-time data.
- If you don't, the data is cached and refreshed once a day. How long the data is cached for varies by brokerage. Check the [brokerage integrations doc](https://support.snaptrade.com/brokerages-table?v=d16c4c97b8d5438bbb2d8581ac53b11e) and look for "Cache Expiry Time" to see the exact value for a specific brokerage. If you need real-time, use the [manual refresh](/reference/Connections/Connections_refreshBrokerageAuthorization) endpoint.
If the connection has become disabled, it can no longer access the latest data from the brokerage, but will continue to return the last available cached state. Please see [this guide](/docs/fix-broken-connections) on how to fix a disabled connection.
526 527 528 529 |
# File 'lib/snaptrade/api/account_information_api.rb', line 526 def get_user_account_balance(user_id:, user_secret:, account_id:, extra: {}) data, _status_code, _headers = get_user_account_balance_with_http_info_impl(user_id, user_secret, account_id, extra) data end |
#get_user_account_balance_with_http_info(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
List account balances
Returns a list of balances for the account. Each element of the list has a distinct currency. Some brokerages like Questrade [allows holding multiple currencies in the same account](www.questrade.com/learning/questrade-basics/balances-and-reports/understanding-your-account-balances).
Check your API key on the [Customer Dashboard billing page](dashboard.snaptrade.com/settings/billing) to see if you have real-time data access:
- If you do, this endpoint returns real-time data.
- If you don't, the data is cached and refreshed once a day. How long the data is cached for varies by brokerage. Check the [brokerage integrations doc](https://support.snaptrade.com/brokerages-table?v=d16c4c97b8d5438bbb2d8581ac53b11e) and look for "Cache Expiry Time" to see the exact value for a specific brokerage. If you need real-time, use the [manual refresh](/reference/Connections/Connections_refreshBrokerageAuthorization) endpoint.
If the connection has become disabled, it can no longer access the latest data from the brokerage, but will continue to return the last available cached state. Please see [this guide](/docs/fix-broken-connections) on how to fix a disabled connection.
545 546 547 |
# File 'lib/snaptrade/api/account_information_api.rb', line 545 def get_user_account_balance_with_http_info(user_id:, user_secret:, account_id:, extra: {}) get_user_account_balance_with_http_info_impl(user_id, user_secret, account_id, extra) end |
#get_user_account_details(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
Get account detail
Returns account detail known to SnapTrade for the specified account.
Check your API key on the [Customer Dashboard billing page](dashboard.snaptrade.com/settings/billing) to see if you have real-time data access:
- If you do, this endpoint returns real-time data.
- If you don't, the data is cached and refreshed once a day. If you need real-time, use the [manual refresh](/reference/Connections/Connections_refreshBrokerageAuthorization) endpoint.
If the connection has become disabled, it can no longer access the latest data from the brokerage, but will continue to return the last available cached state. Please see [this guide](/docs/fix-broken-connections) on how to fix a disabled connection.
641 642 643 644 |
# File 'lib/snaptrade/api/account_information_api.rb', line 641 def get_user_account_details(user_id:, user_secret:, account_id:, extra: {}) data, _status_code, _headers = get_user_account_details_with_http_info_impl(user_id, user_secret, account_id, extra) data end |
#get_user_account_details_with_http_info(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
Get account detail
Returns account detail known to SnapTrade for the specified account.
Check your API key on the [Customer Dashboard billing page](dashboard.snaptrade.com/settings/billing) to see if you have real-time data access:
- If you do, this endpoint returns real-time data.
- If you don't, the data is cached and refreshed once a day. If you need real-time, use the [manual refresh](/reference/Connections/Connections_refreshBrokerageAuthorization) endpoint.
If the connection has become disabled, it can no longer access the latest data from the brokerage, but will continue to return the last available cached state. Please see [this guide](/docs/fix-broken-connections) on how to fix a disabled connection.
660 661 662 |
# File 'lib/snaptrade/api/account_information_api.rb', line 660 def get_user_account_details_with_http_info(user_id:, user_secret:, account_id:, extra: {}) get_user_account_details_with_http_info_impl(user_id, user_secret, account_id, extra) end |
#get_user_account_order_detail(brokerage_order_id:, account_id:, user_id:, user_secret:, extra: {}) ⇒ Object
Get account order detail
Returns the detail of a single order using the external order ID provided in the request body.
This endpoint only works for single-leg orders at this time. Support for multi-leg orders will be added in the future.
This endpoint is always realtime and does not rely on cached data.
This endpoint only returns orders placed through SnapTrade. In other words, orders placed outside of the SnapTrade network are not returned by this endpoint.
758 759 760 761 762 763 764 |
# File 'lib/snaptrade/api/account_information_api.rb', line 758 def get_user_account_order_detail(brokerage_order_id:, account_id:, user_id:, user_secret:, extra: {}) _body = {} _body[:brokerage_order_id] = brokerage_order_id if brokerage_order_id != SENTINEL account_information_get_user_account_order_detail_request = _body data, _status_code, _headers = get_user_account_order_detail_with_http_info_impl(account_id, user_id, user_secret, account_information_get_user_account_order_detail_request, extra) data end |
#get_user_account_order_detail_with_http_info(brokerage_order_id:, account_id:, user_id:, user_secret:, extra: {}) ⇒ Object
Get account order detail
Returns the detail of a single order using the external order ID provided in the request body.
This endpoint only works for single-leg orders at this time. Support for multi-leg orders will be added in the future.
This endpoint is always realtime and does not rely on cached data.
This endpoint only returns orders placed through SnapTrade. In other words, orders placed outside of the SnapTrade network are not returned by this endpoint.
782 783 784 785 786 787 |
# File 'lib/snaptrade/api/account_information_api.rb', line 782 def get_user_account_order_detail_with_http_info(brokerage_order_id:, account_id:, user_id:, user_secret:, extra: {}) _body = {} _body[:brokerage_order_id] = brokerage_order_id if brokerage_order_id != SENTINEL account_information_get_user_account_order_detail_request = _body get_user_account_order_detail_with_http_info_impl(account_id, user_id, user_secret, account_information_get_user_account_order_detail_request, extra) end |
#get_user_account_orders(user_id:, user_secret:, account_id:, state: SENTINEL, days: SENTINEL, extra: {}) ⇒ Object
List account orders
Returns a list of recent orders in the specified account.
Check your API key on the [Customer Dashboard billing page](dashboard.snaptrade.com/settings/billing) to see if you have real-time data access:
- If you do, this endpoint returns real-time data.
- If you don't, the data is cached and refreshed once a day. How long the data is cached for varies by brokerage. Check the [brokerage integrations doc](https://support.snaptrade.com/brokerages-table?v=d16c4c97b8d5438bbb2d8581ac53b11e) and look for "Cache Expiry Time" to see the exact value for a specific brokerage. If you need real-time, use the [manual refresh](/reference/Connections/Connections_refreshBrokerageAuthorization) endpoint.
If the connection has become disabled, it can no longer access the latest data from the brokerage, but will continue to return the last available cached state. Please see [this guide](/docs/fix-broken-connections) on how to fix a disabled connection.
894 895 896 897 898 899 |
# File 'lib/snaptrade/api/account_information_api.rb', line 894 def get_user_account_orders(user_id:, user_secret:, account_id:, state: SENTINEL, days: SENTINEL, extra: {}) extra[:state] = state if state != SENTINEL extra[:days] = days if days != SENTINEL data, _status_code, _headers = get_user_account_orders_with_http_info_impl(user_id, user_secret, account_id, extra) data end |
#get_user_account_orders_with_http_info(user_id:, user_secret:, account_id:, state: SENTINEL, days: SENTINEL, extra: {}) ⇒ Object
List account orders
Returns a list of recent orders in the specified account.
Check your API key on the [Customer Dashboard billing page](dashboard.snaptrade.com/settings/billing) to see if you have real-time data access:
- If you do, this endpoint returns real-time data.
- If you don't, the data is cached and refreshed once a day. How long the data is cached for varies by brokerage. Check the [brokerage integrations doc](https://support.snaptrade.com/brokerages-table?v=d16c4c97b8d5438bbb2d8581ac53b11e) and look for "Cache Expiry Time" to see the exact value for a specific brokerage. If you need real-time, use the [manual refresh](/reference/Connections/Connections_refreshBrokerageAuthorization) endpoint.
If the connection has become disabled, it can no longer access the latest data from the brokerage, but will continue to return the last available cached state. Please see [this guide](/docs/fix-broken-connections) on how to fix a disabled connection.
917 918 919 920 921 |
# File 'lib/snaptrade/api/account_information_api.rb', line 917 def get_user_account_orders_with_http_info(user_id:, user_secret:, account_id:, state: SENTINEL, days: SENTINEL, extra: {}) extra[:state] = state if state != SENTINEL extra[:days] = days if days != SENTINEL get_user_account_orders_with_http_info_impl(user_id, user_secret, account_id, extra) end |
#get_user_account_positions(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
List account positions
Returns a list of stock/ETF/crypto/mutual fund positions in the specified account. For option positions, please use the [options endpoint](/reference/Options/Options_listOptionHoldings).
Consider using the newer [unified positions endpoint](/reference/Account%20Information/AccountInformation_getAllAccountPositions). This will allow you to get both equity and option positions in a single call, as well as additional asset classes such as futures.
Check your API key on the [Customer Dashboard billing page](dashboard.snaptrade.com/settings/billing) to see if you have real-time data access:
- If you do, this endpoint returns real-time data.
- If you don't, the data is cached and refreshed once a day. How long the data is cached for varies by brokerage. Check the [brokerage integrations doc](https://support.snaptrade.com/brokerages-table?v=d16c4c97b8d5438bbb2d8581ac53b11e) and look for "Cache Expiry Time" to see the exact value for a specific brokerage. If you need real-time, use the [manual refresh](/reference/Connections/Connections_refreshBrokerageAuthorization) endpoint.
If the connection has become disabled, it can no longer access the latest data from the brokerage, but will continue to return the last available cached state. Please see [this guide](/docs/fix-broken-connections) on how to fix a disabled connection.
1035 1036 1037 1038 |
# File 'lib/snaptrade/api/account_information_api.rb', line 1035 def get_user_account_positions(user_id:, user_secret:, account_id:, extra: {}) data, _status_code, _headers = get_user_account_positions_with_http_info_impl(user_id, user_secret, account_id, extra) data end |
#get_user_account_positions_with_http_info(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
List account positions
Returns a list of stock/ETF/crypto/mutual fund positions in the specified account. For option positions, please use the [options endpoint](/reference/Options/Options_listOptionHoldings).
Consider using the newer [unified positions endpoint](/reference/Account%20Information/AccountInformation_getAllAccountPositions). This will allow you to get both equity and option positions in a single call, as well as additional asset classes such as futures.
Check your API key on the [Customer Dashboard billing page](dashboard.snaptrade.com/settings/billing) to see if you have real-time data access:
- If you do, this endpoint returns real-time data.
- If you don't, the data is cached and refreshed once a day. How long the data is cached for varies by brokerage. Check the [brokerage integrations doc](https://support.snaptrade.com/brokerages-table?v=d16c4c97b8d5438bbb2d8581ac53b11e) and look for "Cache Expiry Time" to see the exact value for a specific brokerage. If you need real-time, use the [manual refresh](/reference/Connections/Connections_refreshBrokerageAuthorization) endpoint.
If the connection has become disabled, it can no longer access the latest data from the brokerage, but will continue to return the last available cached state. Please see [this guide](/docs/fix-broken-connections) on how to fix a disabled connection.
1056 1057 1058 |
# File 'lib/snaptrade/api/account_information_api.rb', line 1056 def get_user_account_positions_with_http_info(user_id:, user_secret:, account_id:, extra: {}) get_user_account_positions_with_http_info_impl(user_id, user_secret, account_id, extra) end |
#get_user_account_recent_orders(user_id:, user_secret:, account_id:, only_executed: SENTINEL, extra: {}) ⇒ Object
List account recent orders (last 24 hours only)
A lightweight endpoint that returns the latest page of orders placed in the last 24 hours in the specified account. For most brokerages, the default page size is 100 meaning the endpoint will return a max of 100 orders. This endpoint is realtime and can be used to quickly check if account state has recently changed due to an execution, or check status of recently placed orders Differs from /orders in that it is always realtime, and only checks the last 24 hours By default only returns executed orders, but that can be changed by setting only_executed to false
1150 1151 1152 1153 1154 |
# File 'lib/snaptrade/api/account_information_api.rb', line 1150 def get_user_account_recent_orders(user_id:, user_secret:, account_id:, only_executed: SENTINEL, extra: {}) extra[:only_executed] = only_executed if only_executed != SENTINEL data, _status_code, _headers = get_user_account_recent_orders_with_http_info_impl(user_id, user_secret, account_id, extra) data end |
#get_user_account_recent_orders_with_http_info(user_id:, user_secret:, account_id:, only_executed: SENTINEL, extra: {}) ⇒ Object
List account recent orders (last 24 hours only)
A lightweight endpoint that returns the latest page of orders placed in the last 24 hours in the specified account. For most brokerages, the default page size is 100 meaning the endpoint will return a max of 100 orders. This endpoint is realtime and can be used to quickly check if account state has recently changed due to an execution, or check status of recently placed orders Differs from /orders in that it is always realtime, and only checks the last 24 hours By default only returns executed orders, but that can be changed by setting only_executed to false
1168 1169 1170 1171 |
# File 'lib/snaptrade/api/account_information_api.rb', line 1168 def get_user_account_recent_orders_with_http_info(user_id:, user_secret:, account_id:, only_executed: SENTINEL, extra: {}) extra[:only_executed] = only_executed if only_executed != SENTINEL get_user_account_recent_orders_with_http_info_impl(user_id, user_secret, account_id, extra) end |
#get_user_account_return_rates(user_id:, user_secret:, account_id:, timeframes: SENTINEL, extra: {}) ⇒ Object
List account rate of returns
Returns a list of rate of return percents for a given account.
1263 1264 1265 1266 1267 |
# File 'lib/snaptrade/api/account_information_api.rb', line 1263 def get_user_account_return_rates(user_id:, user_secret:, account_id:, timeframes: SENTINEL, extra: {}) extra[:timeframes] = timeframes if timeframes != SENTINEL data, _status_code, _headers = get_user_account_return_rates_with_http_info_impl(user_id, user_secret, account_id, extra) data end |
#get_user_account_return_rates_with_http_info(user_id:, user_secret:, account_id:, timeframes: SENTINEL, extra: {}) ⇒ Object
List account rate of returns
Returns a list of rate of return percents for a given account.
1278 1279 1280 1281 |
# File 'lib/snaptrade/api/account_information_api.rb', line 1278 def get_user_account_return_rates_with_http_info(user_id:, user_secret:, account_id:, timeframes: SENTINEL, extra: {}) extra[:timeframes] = timeframes if timeframes != SENTINEL get_user_account_return_rates_with_http_info_impl(user_id, user_secret, account_id, extra) end |
#get_user_holdings(account_id:, user_id:, user_secret:, extra: {}) ⇒ Object
List account holdings
Returns a list of balances, positions, and recent orders for the specified account. The data returned is similar to the data returned over the more fine-grained [balances](/reference/Account%20Information/AccountInformation_getUserAccountBalance), [positions](/reference/Account%20Information/AccountInformation_getUserAccountPositions) and [orders](/reference/Account%20Information/AccountInformation_getUserAccountOrders) endpoints. __The finer-grained APIs are preferred. They are easier to work with, faster, and have better error handling than this coarse-grained API.__
Check your API key on the [Customer Dashboard billing page](dashboard.snaptrade.com/settings/billing) to see if you have real-time data access:
- If you do, this endpoint returns real-time data.
- If you don't, the data is cached and refreshed once a day. How long the data is cached for varies by brokerage. Check the [brokerage integrations doc](https://support.snaptrade.com/brokerages-table?v=d16c4c97b8d5438bbb2d8581ac53b11e) and look for "Cache Expiry Time" to see the exact value for a specific brokerage. If you need real-time, use the [manual refresh](/reference/Connections/Connections_refreshBrokerageAuthorization) endpoint.
If the connection has become disabled, it can no longer access the latest data from the brokerage, but will continue to return the last available cached state. Please see [this guide](/docs/fix-broken-connections) on how to fix a disabled connection.
1378 1379 1380 1381 |
# File 'lib/snaptrade/api/account_information_api.rb', line 1378 def get_user_holdings(account_id:, user_id:, user_secret:, extra: {}) data, _status_code, _headers = get_user_holdings_with_http_info_impl(account_id, user_id, user_secret, extra) data end |
#get_user_holdings_with_http_info(account_id:, user_id:, user_secret:, extra: {}) ⇒ Object
List account holdings
Returns a list of balances, positions, and recent orders for the specified account. The data returned is similar to the data returned over the more fine-grained [balances](/reference/Account%20Information/AccountInformation_getUserAccountBalance), [positions](/reference/Account%20Information/AccountInformation_getUserAccountPositions) and [orders](/reference/Account%20Information/AccountInformation_getUserAccountOrders) endpoints. __The finer-grained APIs are preferred. They are easier to work with, faster, and have better error handling than this coarse-grained API.__
Check your API key on the [Customer Dashboard billing page](dashboard.snaptrade.com/settings/billing) to see if you have real-time data access:
- If you do, this endpoint returns real-time data.
- If you don't, the data is cached and refreshed once a day. How long the data is cached for varies by brokerage. Check the [brokerage integrations doc](https://support.snaptrade.com/brokerages-table?v=d16c4c97b8d5438bbb2d8581ac53b11e) and look for "Cache Expiry Time" to see the exact value for a specific brokerage. If you need real-time, use the [manual refresh](/reference/Connections/Connections_refreshBrokerageAuthorization) endpoint.
If the connection has become disabled, it can no longer access the latest data from the brokerage, but will continue to return the last available cached state. Please see [this guide](/docs/fix-broken-connections) on how to fix a disabled connection.
1397 1398 1399 |
# File 'lib/snaptrade/api/account_information_api.rb', line 1397 def get_user_holdings_with_http_info(account_id:, user_id:, user_secret:, extra: {}) get_user_holdings_with_http_info_impl(account_id, user_id, user_secret, extra) end |
#list_user_accounts(user_id:, user_secret:, extra: {}) ⇒ Object
List accounts
**Deprecated, please use the [list accounts for a connection endpoint](/reference/Connections/Connections_listBrokerageAuthorizationAccounts) instead.**
Returns all brokerage accounts across all connections known to SnapTrade for the authenticated user.
This data is cached and only refreshed once a day, regardless of the customer’s plan. To get real-time data on a real-time plan, use the connection-scoped endpoint linked above. Customers on delayed plans can force a refresh with the [manual refresh endpoint](/reference/Connections/Connections_refreshBrokerageAuthorization).
1490 1491 1492 1493 |
# File 'lib/snaptrade/api/account_information_api.rb', line 1490 def list_user_accounts(user_id:, user_secret:, extra: {}) data, _status_code, _headers = list_user_accounts_with_http_info_impl(user_id, user_secret, extra) data end |
#list_user_accounts_with_http_info(user_id:, user_secret:, extra: {}) ⇒ Object
List accounts
**Deprecated, please use the [list accounts for a connection endpoint](/reference/Connections/Connections_listBrokerageAuthorizationAccounts) instead.**
Returns all brokerage accounts across all connections known to SnapTrade for the authenticated user.
This data is cached and only refreshed once a day, regardless of the customer’s plan. To get real-time data on a real-time plan, use the connection-scoped endpoint linked above. Customers on delayed plans can force a refresh with the [manual refresh endpoint](/reference/Connections/Connections_refreshBrokerageAuthorization).
1506 1507 1508 |
# File 'lib/snaptrade/api/account_information_api.rb', line 1506 def list_user_accounts_with_http_info(user_id:, user_secret:, extra: {}) list_user_accounts_with_http_info_impl(user_id, user_secret, extra) end |
#update_user_account(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
Update details of an investment account
Updates various properties of a specified account.
1590 1591 1592 1593 |
# File 'lib/snaptrade/api/account_information_api.rb', line 1590 def update_user_account(user_id:, user_secret:, account_id:, extra: {}) data, _status_code, _headers = update_user_account_with_http_info_impl(user_id, user_secret, account_id, extra) data end |
#update_user_account_with_http_info(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
Update details of an investment account
Updates various properties of a specified account.
1603 1604 1605 |
# File 'lib/snaptrade/api/account_information_api.rb', line 1603 def update_user_account_with_http_info(user_id:, user_secret:, account_id:, extra: {}) update_user_account_with_http_info_impl(user_id, user_secret, account_id, extra) end |