Class: SnapTrade::AccountOrderRecord
- Inherits:
-
Object
- Object
- SnapTrade::AccountOrderRecord
- Defined in:
- lib/snaptrade/models/account_order_record.rb
Overview
Describes a single recent order in an account. Each record here represents a single order leg. For multi-leg orders, there will be multiple records.
Instance Attribute Summary collapse
-
#action ⇒ Object
The action describes the intent or side of a trade.
-
#brokerage_order_id ⇒ Object
Order ID returned by brokerage.
-
#canceled_quantity ⇒ Object
The number of shares or contracts that have been canceled.
-
#child_brokerage_order_ids ⇒ Object
Returns the value of attribute child_brokerage_order_ids.
-
#execution_price ⇒ Object
The price at which the order was executed.
-
#expiry_date ⇒ Object
The time the order expires.
-
#filled_quantity ⇒ Object
The number of shares or contracts that have been filled.
-
#limit_price ⇒ Object
The limit price is maximum price one is willing to pay for a buy order or the minimum price one is willing to accept for a sell order.
-
#open_quantity ⇒ Object
The number of shares or contracts that are still open (waiting for execution).
-
#option_symbol ⇒ Object
Returns the value of attribute option_symbol.
-
#order_type ⇒ Object
The type of order placed.
-
#quote_currency ⇒ Object
Returns the value of attribute quote_currency.
-
#quote_universal_symbol ⇒ Object
Returns the value of attribute quote_universal_symbol.
-
#status ⇒ Object
Indicates the status of an order.
-
#stop_price ⇒ Object
The stop price is the price at which a stop order is triggered.
-
#symbol ⇒ Object
A unique ID for the security within SnapTrade, scoped to the brokerage account that the security belongs to.
-
#time_executed ⇒ Object
The time the order was executed in the brokerage system.
-
#time_in_force ⇒ Object
The Time in Force type for the order.
-
#time_placed ⇒ Object
The time the order was placed.
-
#time_updated ⇒ Object
The time the order was last updated in the brokerage system.
-
#total_quantity ⇒ Object
The total number of shares or contracts of the order.
-
#trailing_stop ⇒ Object
Returns the value of attribute trailing_stop.
-
#universal_symbol ⇒ Object
Returns the value of attribute universal_symbol.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AccountOrderRecord
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AccountOrderRecord
Initializes the object
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/snaptrade/models/account_order_record.rb', line 163 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SnapTrade::AccountOrderRecord` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SnapTrade::AccountOrderRecord`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'brokerage_order_id') self.brokerage_order_id = attributes[:'brokerage_order_id'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'universal_symbol') self.universal_symbol = attributes[:'universal_symbol'] end if attributes.key?(:'option_symbol') self.option_symbol = attributes[:'option_symbol'] end if attributes.key?(:'quote_universal_symbol') self.quote_universal_symbol = attributes[:'quote_universal_symbol'] end if attributes.key?(:'quote_currency') self.quote_currency = attributes[:'quote_currency'] end if attributes.key?(:'action') self.action = attributes[:'action'] end if attributes.key?(:'total_quantity') self.total_quantity = attributes[:'total_quantity'] end if attributes.key?(:'open_quantity') self.open_quantity = attributes[:'open_quantity'] end if attributes.key?(:'canceled_quantity') self.canceled_quantity = attributes[:'canceled_quantity'] end if attributes.key?(:'filled_quantity') self.filled_quantity = attributes[:'filled_quantity'] end if attributes.key?(:'execution_price') self.execution_price = attributes[:'execution_price'] end if attributes.key?(:'limit_price') self.limit_price = attributes[:'limit_price'] end if attributes.key?(:'stop_price') self.stop_price = attributes[:'stop_price'] end if attributes.key?(:'trailing_stop') self.trailing_stop = attributes[:'trailing_stop'] end if attributes.key?(:'order_type') self.order_type = attributes[:'order_type'] end if attributes.key?(:'time_in_force') self.time_in_force = attributes[:'time_in_force'] end if attributes.key?(:'time_placed') self.time_placed = attributes[:'time_placed'] end if attributes.key?(:'time_updated') self.time_updated = attributes[:'time_updated'] end if attributes.key?(:'time_executed') self.time_executed = attributes[:'time_executed'] end if attributes.key?(:'expiry_date') self.expiry_date = attributes[:'expiry_date'] end if attributes.key?(:'symbol') self.symbol = attributes[:'symbol'] end if attributes.key?(:'child_brokerage_order_ids') self.child_brokerage_order_ids = attributes[:'child_brokerage_order_ids'] end end |
Instance Attribute Details
#action ⇒ Object
The action describes the intent or side of a trade. This is usually ‘BUY` or `SELL` but can include other potential values like the following depending on the specific brokerage. - BUY - SELL - BUY_COVER - SELL_SHORT - BUY_OPEN - BUY_CLOSE - SELL_OPEN - SELL_CLOSE
31 32 33 |
# File 'lib/snaptrade/models/account_order_record.rb', line 31 def action @action end |
#brokerage_order_id ⇒ Object
Order ID returned by brokerage. This is the unique identifier for the order in the brokerage system.
17 18 19 |
# File 'lib/snaptrade/models/account_order_record.rb', line 17 def brokerage_order_id @brokerage_order_id end |
#canceled_quantity ⇒ Object
The number of shares or contracts that have been canceled. Can be a decimal number for fractional shares.
40 41 42 |
# File 'lib/snaptrade/models/account_order_record.rb', line 40 def canceled_quantity @canceled_quantity end |
#child_brokerage_order_ids ⇒ Object
Returns the value of attribute child_brokerage_order_ids.
77 78 79 |
# File 'lib/snaptrade/models/account_order_record.rb', line 77 def child_brokerage_order_ids @child_brokerage_order_ids end |
#execution_price ⇒ Object
The price at which the order was executed. For option orders, this represents the price per share.
46 47 48 |
# File 'lib/snaptrade/models/account_order_record.rb', line 46 def execution_price @execution_price end |
#expiry_date ⇒ Object
The time the order expires. This value is not always available from the brokerage.
72 73 74 |
# File 'lib/snaptrade/models/account_order_record.rb', line 72 def expiry_date @expiry_date end |
#filled_quantity ⇒ Object
The number of shares or contracts that have been filled. Can be a decimal number for fractional shares.
43 44 45 |
# File 'lib/snaptrade/models/account_order_record.rb', line 43 def filled_quantity @filled_quantity end |
#limit_price ⇒ Object
The limit price is maximum price one is willing to pay for a buy order or the minimum price one is willing to accept for a sell order. Should only apply to ‘Limit` and `StopLimit` orders. For option orders, this represents the price per share.
49 50 51 |
# File 'lib/snaptrade/models/account_order_record.rb', line 49 def limit_price @limit_price end |
#open_quantity ⇒ Object
The number of shares or contracts that are still open (waiting for execution). Can be a decimal number for fractional shares.
37 38 39 |
# File 'lib/snaptrade/models/account_order_record.rb', line 37 def open_quantity @open_quantity end |
#option_symbol ⇒ Object
Returns the value of attribute option_symbol.
24 25 26 |
# File 'lib/snaptrade/models/account_order_record.rb', line 24 def option_symbol @option_symbol end |
#order_type ⇒ Object
The type of order placed. The most common values are ‘Market`, `Limit`, `Stop`, and `StopLimit`. We try our best to map brokerage order types to these values. When mapping fails, we will return the brokerage’s order type value.
57 58 59 |
# File 'lib/snaptrade/models/account_order_record.rb', line 57 def order_type @order_type end |
#quote_currency ⇒ Object
Returns the value of attribute quote_currency.
28 29 30 |
# File 'lib/snaptrade/models/account_order_record.rb', line 28 def quote_currency @quote_currency end |
#quote_universal_symbol ⇒ Object
Returns the value of attribute quote_universal_symbol.
26 27 28 |
# File 'lib/snaptrade/models/account_order_record.rb', line 26 def quote_universal_symbol @quote_universal_symbol end |
#status ⇒ Object
Indicates the status of an order. SnapTrade does a best effort to map brokerage statuses to statuses in this enum. Possible values include: - NONE - PENDING - ACCEPTED - FAILED - REJECTED - CANCELED - PARTIAL_CANCELED - CANCEL_PENDING - EXECUTED - PARTIAL - REPLACE_PENDING - REPLACED - EXPIRED - QUEUED - TRIGGERED - ACTIVATED
20 21 22 |
# File 'lib/snaptrade/models/account_order_record.rb', line 20 def status @status end |
#stop_price ⇒ Object
The stop price is the price at which a stop order is triggered. Should only apply to ‘Stop` and `StopLimit` orders. For option orders, this represents the price per share.
52 53 54 |
# File 'lib/snaptrade/models/account_order_record.rb', line 52 def stop_price @stop_price end |
#symbol ⇒ Object
A unique ID for the security within SnapTrade, scoped to the brokerage account that the security belongs to. This is a legacy field and should not be used. Do not rely on this being a stable ID as it can change.
75 76 77 |
# File 'lib/snaptrade/models/account_order_record.rb', line 75 def symbol @symbol end |
#time_executed ⇒ Object
The time the order was executed in the brokerage system. This value is not always available from the brokerage.
69 70 71 |
# File 'lib/snaptrade/models/account_order_record.rb', line 69 def time_executed @time_executed end |
#time_in_force ⇒ Object
The Time in Force type for the order. This field indicates how long the order will remain active before it is executed or expires. We try our best to map brokerage time in force values to the following. When mapping fails, we will return the brokerage’s time in force value. - ‘Day` - Day. The order is valid only for the trading day on which it is placed. - `GTC` - Good Til Canceled. The order is valid until it is executed or canceled. - `FOK` - Fill Or Kill. The order must be executed in its entirety immediately or be canceled completely. - `IOC` - Immediate Or Cancel. The order must be executed immediately. Any portion of the order that cannot be filled immediately will be canceled. - `GTD` - Good Til Date. The order is valid until the specified date. - `MOO` - Market On Open. The order is to be executed at the day’s opening price. - ‘EHP` - Extended Hours P.M. The order is to be placed during extended hour trading, after markets close.
60 61 62 |
# File 'lib/snaptrade/models/account_order_record.rb', line 60 def time_in_force @time_in_force end |
#time_placed ⇒ Object
The time the order was placed. This is the time the order was submitted to the brokerage.
63 64 65 |
# File 'lib/snaptrade/models/account_order_record.rb', line 63 def time_placed @time_placed end |
#time_updated ⇒ Object
The time the order was last updated in the brokerage system. This value is not always available from the brokerage.
66 67 68 |
# File 'lib/snaptrade/models/account_order_record.rb', line 66 def time_updated @time_updated end |
#total_quantity ⇒ Object
The total number of shares or contracts of the order. This should be the sum of the filled, canceled, and open quantities. Can be a decimal number for fractional shares.
34 35 36 |
# File 'lib/snaptrade/models/account_order_record.rb', line 34 def total_quantity @total_quantity end |
#trailing_stop ⇒ Object
Returns the value of attribute trailing_stop.
54 55 56 |
# File 'lib/snaptrade/models/account_order_record.rb', line 54 def trailing_stop @trailing_stop end |
#universal_symbol ⇒ Object
Returns the value of attribute universal_symbol.
22 23 24 |
# File 'lib/snaptrade/models/account_order_record.rb', line 22 def universal_symbol @universal_symbol end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
109 110 111 |
# File 'lib/snaptrade/models/account_order_record.rb', line 109 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/snaptrade/models/account_order_record.rb', line 80 def self.attribute_map { :'brokerage_order_id' => :'brokerage_order_id', :'status' => :'status', :'universal_symbol' => :'universal_symbol', :'option_symbol' => :'option_symbol', :'quote_universal_symbol' => :'quote_universal_symbol', :'quote_currency' => :'quote_currency', :'action' => :'action', :'total_quantity' => :'total_quantity', :'open_quantity' => :'open_quantity', :'canceled_quantity' => :'canceled_quantity', :'filled_quantity' => :'filled_quantity', :'execution_price' => :'execution_price', :'limit_price' => :'limit_price', :'stop_price' => :'stop_price', :'trailing_stop' => :'trailing_stop', :'order_type' => :'order_type', :'time_in_force' => :'time_in_force', :'time_placed' => :'time_placed', :'time_updated' => :'time_updated', :'time_executed' => :'time_executed', :'expiry_date' => :'expiry_date', :'symbol' => :'symbol', :'child_brokerage_order_ids' => :'child_brokerage_order_ids' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
327 328 329 |
# File 'lib/snaptrade/models/account_order_record.rb', line 327 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/snaptrade/models/account_order_record.rb', line 143 def self.openapi_nullable Set.new([ :'total_quantity', :'open_quantity', :'canceled_quantity', :'filled_quantity', :'execution_price', :'limit_price', :'stop_price', :'trailing_stop', :'order_type', :'time_updated', :'time_executed', :'expiry_date', :'child_brokerage_order_ids' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/snaptrade/models/account_order_record.rb', line 114 def self.openapi_types { :'brokerage_order_id' => :'String', :'status' => :'AccountOrderRecordStatus', :'universal_symbol' => :'AccountOrderRecordUniversalSymbol', :'option_symbol' => :'AccountOrderRecordOptionSymbol', :'quote_universal_symbol' => :'AccountOrderRecordQuoteUniversalSymbol', :'quote_currency' => :'AccountOrderRecordQuoteCurrency', :'action' => :'String', :'total_quantity' => :'String', :'open_quantity' => :'String', :'canceled_quantity' => :'String', :'filled_quantity' => :'String', :'execution_price' => :'Float', :'limit_price' => :'Float', :'stop_price' => :'Float', :'trailing_stop' => :'AccountOrderRecordTrailingStop', :'order_type' => :'String', :'time_in_force' => :'String', :'time_placed' => :'Time', :'time_updated' => :'Time', :'time_executed' => :'Time', :'expiry_date' => :'Time', :'symbol' => :'String', :'child_brokerage_order_ids' => :'AccountOrderRecordChildBrokerageOrderIds' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/snaptrade/models/account_order_record.rb', line 284 def ==(o) return true if self.equal?(o) self.class == o.class && brokerage_order_id == o.brokerage_order_id && status == o.status && universal_symbol == o.universal_symbol && option_symbol == o.option_symbol && quote_universal_symbol == o.quote_universal_symbol && quote_currency == o.quote_currency && action == o.action && total_quantity == o.total_quantity && open_quantity == o.open_quantity && canceled_quantity == o.canceled_quantity && filled_quantity == o.filled_quantity && execution_price == o.execution_price && limit_price == o.limit_price && stop_price == o.stop_price && trailing_stop == o.trailing_stop && order_type == o.order_type && time_in_force == o.time_in_force && time_placed == o.time_placed && time_updated == o.time_updated && time_executed == o.time_executed && expiry_date == o.expiry_date && symbol == o.symbol && child_brokerage_order_ids == o.child_brokerage_order_ids end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/snaptrade/models/account_order_record.rb', line 358 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = SnapTrade.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
429 430 431 432 433 434 435 436 437 438 439 440 441 |
# File 'lib/snaptrade/models/account_order_record.rb', line 429 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/snaptrade/models/account_order_record.rb', line 334 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
314 315 316 |
# File 'lib/snaptrade/models/account_order_record.rb', line 314 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
320 321 322 |
# File 'lib/snaptrade/models/account_order_record.rb', line 320 def hash [brokerage_order_id, status, universal_symbol, option_symbol, quote_universal_symbol, quote_currency, action, total_quantity, open_quantity, canceled_quantity, filled_quantity, execution_price, limit_price, stop_price, trailing_stop, order_type, time_in_force, time_placed, time_updated, time_executed, expiry_date, symbol, child_brokerage_order_ids].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
271 272 273 274 |
# File 'lib/snaptrade/models/account_order_record.rb', line 271 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
405 406 407 |
# File 'lib/snaptrade/models/account_order_record.rb', line 405 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
411 412 413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/snaptrade/models/account_order_record.rb', line 411 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
399 400 401 |
# File 'lib/snaptrade/models/account_order_record.rb', line 399 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
278 279 280 |
# File 'lib/snaptrade/models/account_order_record.rb', line 278 def valid? true end |