Class: SnapTrade::AccountOrderRecordV2
- Inherits:
-
Object
- Object
- SnapTrade::AccountOrderRecordV2
- Defined in:
- lib/snaptrade/models/account_order_record_v2.rb
Overview
Describes a single order in the standardized V2 format.
Instance Attribute Summary collapse
-
#brokerage_group_order_id ⇒ Object
The brokerage-assigned identifier that links all orders within a complex order (OCO, OTO, OTOCO) together.
-
#brokerage_order_id ⇒ Object
Order ID returned by brokerage.
-
#execution_price ⇒ Object
The price at which the order was executed.
-
#legs ⇒ Object
List of legs that make up the order.
-
#limit_price ⇒ Object
The limit price is maximum price one is willing to pay for a buy order or the minimum price one is willing to accept for a sell order.
-
#order_role ⇒ Object
The role of this order within a complex order group (OCO, OTO, OTOCO).
-
#order_type ⇒ Object
The type of order placed.
-
#price_currency ⇒ Object
Price currency code for the order.
-
#price_effect ⇒ Object
Direction of the net order price.
-
#status ⇒ Object
Indicates the status of an order.
-
#stop_price ⇒ Object
The stop price is the price at which a stop order is triggered.
-
#time_executed ⇒ Object
The time the order was executed in the brokerage system.
-
#time_in_force ⇒ Object
The Time in Force type for the order.
-
#time_placed ⇒ Object
The time the order was placed.
-
#trailing_stop ⇒ Object
Returns the value of attribute trailing_stop.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AccountOrderRecordV2
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AccountOrderRecordV2
Initializes the object
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 123 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SnapTrade::AccountOrderRecordV2` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SnapTrade::AccountOrderRecordV2`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'brokerage_order_id') self.brokerage_order_id = attributes[:'brokerage_order_id'] end if attributes.key?(:'brokerage_group_order_id') self.brokerage_group_order_id = attributes[:'brokerage_group_order_id'] end if attributes.key?(:'order_role') self.order_role = attributes[:'order_role'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'order_type') self.order_type = attributes[:'order_type'] end if attributes.key?(:'time_in_force') self.time_in_force = attributes[:'time_in_force'] end if attributes.key?(:'time_placed') self.time_placed = attributes[:'time_placed'] end if attributes.key?(:'time_executed') self.time_executed = attributes[:'time_executed'] end if attributes.key?(:'price_currency') self.price_currency = attributes[:'price_currency'] end if attributes.key?(:'price_effect') self.price_effect = attributes[:'price_effect'] end if attributes.key?(:'execution_price') self.execution_price = attributes[:'execution_price'] end if attributes.key?(:'limit_price') self.limit_price = attributes[:'limit_price'] end if attributes.key?(:'stop_price') self.stop_price = attributes[:'stop_price'] end if attributes.key?(:'trailing_stop') self.trailing_stop = attributes[:'trailing_stop'] end if attributes.key?(:'legs') if (value = attributes[:'legs']).is_a?(Array) self.legs = value end end end |
Instance Attribute Details
#brokerage_group_order_id ⇒ Object
The brokerage-assigned identifier that links all orders within a complex order (OCO, OTO, OTOCO) together. Null for non-complex orders or when the brokerage does not return a group identifier.
20 21 22 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 20 def brokerage_group_order_id @brokerage_group_order_id end |
#brokerage_order_id ⇒ Object
Order ID returned by brokerage. This is the unique identifier for the order in the brokerage system.
17 18 19 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 17 def brokerage_order_id @brokerage_order_id end |
#execution_price ⇒ Object
The price at which the order was executed.
47 48 49 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 47 def execution_price @execution_price end |
#legs ⇒ Object
List of legs that make up the order.
58 59 60 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 58 def legs @legs end |
#limit_price ⇒ Object
The limit price is maximum price one is willing to pay for a buy order or the minimum price one is willing to accept for a sell order. Should only apply to Limit and StopLimit orders.
50 51 52 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 50 def limit_price @limit_price end |
#order_role ⇒ Object
The role of this order within a complex order group (OCO, OTO, OTOCO). Null for non-complex orders.
23 24 25 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 23 def order_role @order_role end |
#order_type ⇒ Object
The type of order placed. - MARKET - LIMIT - STOP - STOP_LIMIT
29 30 31 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 29 def order_type @order_type end |
#price_currency ⇒ Object
Price currency code for the order.
41 42 43 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 41 def price_currency @price_currency end |
#price_effect ⇒ Object
Direction of the net order price. CREDIT means cash is received, DEBIT means cash is paid, EVEN means the net price is zero, and UNKNOWN means the direction could not be determined.
44 45 46 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 44 def price_effect @price_effect end |
#status ⇒ Object
Indicates the status of an order. SnapTrade does a best effort to map brokerage statuses to statuses in this enum. Possible values include: - NONE - PENDING - ACCEPTED - FAILED - REJECTED - CANCELED - PARTIAL_CANCELED - CANCEL_PENDING - EXECUTED - PARTIAL - REPLACE_PENDING - REPLACED - EXPIRED - QUEUED - TRIGGERED - ACTIVATED
26 27 28 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 26 def status @status end |
#stop_price ⇒ Object
The stop price is the price at which a stop order is triggered. Should only apply to Stop and StopLimit orders.
53 54 55 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 53 def stop_price @stop_price end |
#time_executed ⇒ Object
The time the order was executed in the brokerage system. This value is not always available from the brokerage.
38 39 40 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 38 def time_executed @time_executed end |
#time_in_force ⇒ Object
The Time in Force type for the order. This field indicates how long the order will remain active before it is executed or expires. We try our best to map brokerage time in force values to the following. When mapping fails, we will return the brokerage's time in force value. - DAY - Day. The order is valid only for the trading day on which it is placed. - GTC - Good Til Canceled. The order is valid until it is executed or canceled. - FOK - Fill Or Kill. The order must be executed in its entirety immediately or be canceled completely. - IOC - Immediate Or Cancel. The order must be executed immediately. Any portion of the order that cannot be filled immediately will be canceled. - GTD - Good Til Date. The order is valid until the specified date. - MOO - Market On Open. The order is to be executed at the day's opening price. - EHP - Extended Hours P.M. The order is to be placed during extended hour trading, after markets close.
32 33 34 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 32 def time_in_force @time_in_force end |
#time_placed ⇒ Object
The time the order was placed. This is the time the order was submitted to the brokerage.
35 36 37 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 35 def time_placed @time_placed end |
#trailing_stop ⇒ Object
Returns the value of attribute trailing_stop.
55 56 57 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 55 def trailing_stop @trailing_stop end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
82 83 84 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 82 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 61 def self.attribute_map { :'brokerage_order_id' => :'brokerage_order_id', :'brokerage_group_order_id' => :'brokerage_group_order_id', :'order_role' => :'order_role', :'status' => :'status', :'order_type' => :'order_type', :'time_in_force' => :'time_in_force', :'time_placed' => :'time_placed', :'time_executed' => :'time_executed', :'price_currency' => :'price_currency', :'price_effect' => :'price_effect', :'execution_price' => :'execution_price', :'limit_price' => :'limit_price', :'stop_price' => :'stop_price', :'trailing_stop' => :'trailing_stop', :'legs' => :'legs' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
254 255 256 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 254 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 108 def self.openapi_nullable Set.new([ :'brokerage_group_order_id', :'order_role', :'order_type', :'time_executed', :'execution_price', :'limit_price', :'stop_price', :'trailing_stop', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 87 def self.openapi_types { :'brokerage_order_id' => :'String', :'brokerage_group_order_id' => :'String', :'order_role' => :'AccountOrderRecordV2OrderRole', :'status' => :'AccountOrderRecordStatus', :'order_type' => :'String', :'time_in_force' => :'String', :'time_placed' => :'Time', :'time_executed' => :'Time', :'price_currency' => :'String', :'price_effect' => :'PriceEffect', :'execution_price' => :'Float', :'limit_price' => :'Float', :'stop_price' => :'Float', :'trailing_stop' => :'AccountOrderRecordTrailingStop', :'legs' => :'Array<AccountOrderRecordLeg>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 219 def ==(o) return true if self.equal?(o) self.class == o.class && brokerage_order_id == o.brokerage_order_id && brokerage_group_order_id == o.brokerage_group_order_id && order_role == o.order_role && status == o.status && order_type == o.order_type && time_in_force == o.time_in_force && time_placed == o.time_placed && time_executed == o.time_executed && price_currency == o.price_currency && price_effect == o.price_effect && execution_price == o.execution_price && limit_price == o.limit_price && stop_price == o.stop_price && trailing_stop == o.trailing_stop && legs == o.legs end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 285 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = SnapTrade.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 356 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 261 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
241 242 243 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 241 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
247 248 249 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 247 def hash [brokerage_order_id, brokerage_group_order_id, order_role, status, order_type, time_in_force, time_placed, time_executed, price_currency, price_effect, execution_price, limit_price, stop_price, trailing_stop, legs].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
201 202 203 204 205 206 207 208 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 201 def list_invalid_properties invalid_properties = Array.new if @price_effect.nil? invalid_properties.push('invalid value for "price_effect", price_effect cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
332 333 334 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 332 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 338 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
326 327 328 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 326 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
212 213 214 215 |
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 212 def valid? return false if @price_effect.nil? true end |