Class: SnapTrade::AccountOrderRecordV2

Inherits:
Object
  • Object
show all
Defined in:
lib/snaptrade/models/account_order_record_v2.rb

Overview

Describes a single order in the standardized V2 format.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AccountOrderRecordV2

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SnapTrade::AccountOrderRecordV2` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SnapTrade::AccountOrderRecordV2`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'brokerage_order_id')
    self.brokerage_order_id = attributes[:'brokerage_order_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'order_type')
    self.order_type = attributes[:'order_type']
  end

  if attributes.key?(:'time_in_force')
    self.time_in_force = attributes[:'time_in_force']
  end

  if attributes.key?(:'time_placed')
    self.time_placed = attributes[:'time_placed']
  end

  if attributes.key?(:'time_executed')
    self.time_executed = attributes[:'time_executed']
  end

  if attributes.key?(:'quote_currency')
    self.quote_currency = attributes[:'quote_currency']
  end

  if attributes.key?(:'execution_price')
    self.execution_price = attributes[:'execution_price']
  end

  if attributes.key?(:'limit_price')
    self.limit_price = attributes[:'limit_price']
  end

  if attributes.key?(:'stop_price')
    self.stop_price = attributes[:'stop_price']
  end

  if attributes.key?(:'legs')
    if (value = attributes[:'legs']).is_a?(Array)
      self.legs = value
    end
  end
end

Instance Attribute Details

#brokerage_order_idObject

Order ID returned by brokerage. This is the unique identifier for the order in the brokerage system.



17
18
19
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 17

def brokerage_order_id
  @brokerage_order_id
end

#execution_priceObject

The price at which the order was executed.



38
39
40
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 38

def execution_price
  @execution_price
end

#legsObject

List of legs that make up the order.



47
48
49
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 47

def legs
  @legs
end

#limit_priceObject

The limit price is maximum price one is willing to pay for a buy order or the minimum price one is willing to accept for a sell order. Should only apply to ‘Limit` and `StopLimit` orders.



41
42
43
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 41

def limit_price
  @limit_price
end

#order_typeObject

The type of order placed. - ‘MARKET` - `LIMIT` - `STOP` - `STOP_LIMIT`



23
24
25
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 23

def order_type
  @order_type
end

#quote_currencyObject

Quote currency code for the order.



35
36
37
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 35

def quote_currency
  @quote_currency
end

#statusObject

Indicates the status of an order. SnapTrade does a best effort to map brokerage statuses to statuses in this enum. Possible values include: - NONE - PENDING - ACCEPTED - FAILED - REJECTED - CANCELED - PARTIAL_CANCELED - CANCEL_PENDING - EXECUTED - PARTIAL - REPLACE_PENDING - REPLACED - EXPIRED - QUEUED - TRIGGERED - ACTIVATED



20
21
22
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 20

def status
  @status
end

#stop_priceObject

The stop price is the price at which a stop order is triggered. Should only apply to ‘Stop` and `StopLimit` orders.



44
45
46
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 44

def stop_price
  @stop_price
end

#time_executedObject

The time the order was executed in the brokerage system. This value is not always available from the brokerage.



32
33
34
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 32

def time_executed
  @time_executed
end

#time_in_forceObject

The Time in Force type for the order. This field indicates how long the order will remain active before it is executed or expires. We try our best to map brokerage time in force values to the following. When mapping fails, we will return the brokerage’s time in force value. - ‘DAY` - Day. The order is valid only for the trading day on which it is placed. - `GTC` - Good Til Canceled. The order is valid until it is executed or canceled. - `FOK` - Fill Or Kill. The order must be executed in its entirety immediately or be canceled completely. - `IOC` - Immediate Or Cancel. The order must be executed immediately. Any portion of the order that cannot be filled immediately will be canceled. - `GTD` - Good Til Date. The order is valid until the specified date. - `MOO` - Market On Open. The order is to be executed at the day’s opening price. - ‘EHP` - Extended Hours P.M. The order is to be placed during extended hour trading, after markets close.



26
27
28
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 26

def time_in_force
  @time_in_force
end

#time_placedObject

The time the order was placed. This is the time the order was submitted to the brokerage.



29
30
31
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 29

def time_placed
  @time_placed
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



67
68
69
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 67

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 50

def self.attribute_map
  {
    :'brokerage_order_id' => :'brokerage_order_id',
    :'status' => :'status',
    :'order_type' => :'order_type',
    :'time_in_force' => :'time_in_force',
    :'time_placed' => :'time_placed',
    :'time_executed' => :'time_executed',
    :'quote_currency' => :'quote_currency',
    :'execution_price' => :'execution_price',
    :'limit_price' => :'limit_price',
    :'stop_price' => :'stop_price',
    :'legs' => :'legs'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



207
208
209
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 207

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
93
94
95
96
97
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 89

def self.openapi_nullable
  Set.new([
    :'order_type',
    :'time_executed',
    :'execution_price',
    :'limit_price',
    :'stop_price',
  ])
end

.openapi_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 72

def self.openapi_types
  {
    :'brokerage_order_id' => :'String',
    :'status' => :'AccountOrderRecordStatus',
    :'order_type' => :'String',
    :'time_in_force' => :'String',
    :'time_placed' => :'Time',
    :'time_executed' => :'Time',
    :'quote_currency' => :'String',
    :'execution_price' => :'Float',
    :'limit_price' => :'Float',
    :'stop_price' => :'Float',
    :'legs' => :'Array<AccountOrderRecordLeg>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 176

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      brokerage_order_id == o.brokerage_order_id &&
      status == o.status &&
      order_type == o.order_type &&
      time_in_force == o.time_in_force &&
      time_placed == o.time_placed &&
      time_executed == o.time_executed &&
      quote_currency == o.quote_currency &&
      execution_price == o.execution_price &&
      limit_price == o.limit_price &&
      stop_price == o.stop_price &&
      legs == o.legs
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 238

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = SnapTrade.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 309

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 214

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


194
195
196
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 194

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



200
201
202
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 200

def hash
  [brokerage_order_id, status, order_type, time_in_force, time_placed, time_executed, quote_currency, execution_price, limit_price, stop_price, legs].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



163
164
165
166
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 163

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



285
286
287
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 285

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 291

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



279
280
281
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 279

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



170
171
172
# File 'lib/snaptrade/models/account_order_record_v2.rb', line 170

def valid?
  true
end