Class: SnapTrade::BrokerageAuthorization
- Inherits:
-
Object
- Object
- SnapTrade::BrokerageAuthorization
- Defined in:
- lib/snaptrade/models/brokerage_authorization.rb
Overview
A single connection with a brokerage. Note that ‘Connection` and `Brokerage Authorization` are interchangeable, but the term `Connection` is preferred and used in the doc for consistency. A connection is usually tied to a single login at a brokerage. A single connection can contain multiple brokerage accounts. SnapTrade performs de-duping on connections for a given user. If the user has an existing connection with the brokerage, when connecting the brokerage with the same credentials, SnapTrade will return the existing connection instead of creating a new one.
Instance Attribute Summary collapse
-
#brokerage ⇒ Object
Returns the value of attribute brokerage.
-
#created_date ⇒ Object
Timestamp of when the connection was established in SnapTrade.
-
#disabled ⇒ Object
Whether the connection is disabled.
-
#disabled_date ⇒ Object
Timestamp of when the connection was disabled in SnapTrade.
-
#id ⇒ Object
Unique identifier for the connection.
-
#is_eligible_for_payout ⇒ Object
Whether the connection is eligible for a payout.
-
#meta ⇒ Object
Additional data about the connection.
-
#name ⇒ Object
A short, human-readable name for the connection.
-
#type ⇒ Object
Whether the connection is read-only or trade-enabled.
-
#updated_date ⇒ Object
Timestamp of when the connection was last updated in SnapTrade.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BrokerageAuthorization
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ BrokerageAuthorization
Initializes the object
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 91 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SnapTrade::BrokerageAuthorization` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SnapTrade::BrokerageAuthorization`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'created_date') self.created_date = attributes[:'created_date'] end if attributes.key?(:'brokerage') self.brokerage = attributes[:'brokerage'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'disabled') self.disabled = attributes[:'disabled'] end if attributes.key?(:'disabled_date') self.disabled_date = attributes[:'disabled_date'] end if attributes.key?(:'meta') if (value = attributes[:'meta']).is_a?(Hash) self. = value end end if attributes.key?(:'updated_date') self.updated_date = attributes[:'updated_date'] end if attributes.key?(:'is_eligible_for_payout') self.is_eligible_for_payout = attributes[:'is_eligible_for_payout'] end end |
Instance Attribute Details
#brokerage ⇒ Object
Returns the value of attribute brokerage.
22 23 24 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 22 def brokerage @brokerage end |
#created_date ⇒ Object
Timestamp of when the connection was established in SnapTrade.
20 21 22 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 20 def created_date @created_date end |
#disabled ⇒ Object
Whether the connection is disabled. A disabled connection can no longer access the latest data from the brokerage, but will continue to return the last cached state. A connection can become disabled for many reasons and differs by brokerage. Here are some common scenarios: - The user has changed their username or password at the brokerage. - The user has explicitly removed the access grant at the brokerage. - The session has expired at the brokerage and now requires explicit user re-authentication. Please see [this guide](/docs/fix-broken-connections) on how to fix a disabled connection.
31 32 33 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 31 def disabled @disabled end |
#disabled_date ⇒ Object
Timestamp of when the connection was disabled in SnapTrade.
34 35 36 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 34 def disabled_date @disabled_date end |
#id ⇒ Object
Unique identifier for the connection. This is the UUID used to reference the connection in SnapTrade.
17 18 19 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 17 def id @id end |
#is_eligible_for_payout ⇒ Object
Whether the connection is eligible for a payout. This is an experimental field that is NOT generally available for all partners. Do not use in production without speaking to the SnapTrade team.
43 44 45 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 43 def is_eligible_for_payout @is_eligible_for_payout end |
#meta ⇒ Object
Additional data about the connection. This information is specific to the brokerage and there’s no standard format for this data. This field is deprecated and subject to removal in a future version.
37 38 39 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 37 def @meta end |
#name ⇒ Object
A short, human-readable name for the connection.
25 26 27 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 25 def name @name end |
#type ⇒ Object
Whether the connection is read-only or trade-enabled. A read-only connection can only be used to fetch data, while a trade-enabled connection can be used to place trades. Valid values are ‘read` and `trade`.
28 29 30 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 28 def type @type end |
#updated_date ⇒ Object
Timestamp of when the connection was last updated in SnapTrade. This field is deprecated. Please let us know if you have a valid use case for this field.
40 41 42 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 40 def updated_date @updated_date end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 62 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 46 def self.attribute_map { :'id' => :'id', :'created_date' => :'created_date', :'brokerage' => :'brokerage', :'name' => :'name', :'type' => :'type', :'disabled' => :'disabled', :'disabled_date' => :'disabled_date', :'meta' => :'meta', :'updated_date' => :'updated_date', :'is_eligible_for_payout' => :'is_eligible_for_payout' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
192 193 194 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 192 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
83 84 85 86 87 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 83 def self.openapi_nullable Set.new([ :'disabled_date', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 67 def self.openapi_types { :'id' => :'String', :'created_date' => :'Time', :'brokerage' => :'Brokerage', :'name' => :'String', :'type' => :'String', :'disabled' => :'Boolean', :'disabled_date' => :'Time', :'meta' => :'Hash<String, Object>', :'updated_date' => :'Time', :'is_eligible_for_payout' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 162 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && created_date == o.created_date && brokerage == o.brokerage && name == o.name && type == o.type && disabled == o.disabled && disabled_date == o.disabled_date && == o. && updated_date == o.updated_date && is_eligible_for_payout == o.is_eligible_for_payout end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 223 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = SnapTrade.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 294 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 199 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
179 180 181 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 179 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
185 186 187 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 185 def hash [id, created_date, brokerage, name, type, disabled, disabled_date, , updated_date, is_eligible_for_payout].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
149 150 151 152 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 149 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
270 271 272 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 270 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 276 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
264 265 266 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 264 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
156 157 158 |
# File 'lib/snaptrade/models/brokerage_authorization.rb', line 156 def valid? true end |