Class: SnapTrade::ExperimentalEndpointsApi
- Inherits:
-
Object
- Object
- SnapTrade::ExperimentalEndpointsApi
- Defined in:
- lib/snaptrade/api/experimental_endpoints_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_all_account_positions(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
List all account positions.
-
#get_all_account_positions_with_http_info(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
List all account positions.
-
#get_user_account_order_detail_v2(account_id:, brokerage_order_id:, user_id:, user_secret:, extra: {}) ⇒ Object
Get account order detail (V2).
-
#get_user_account_order_detail_v2_with_http_info(account_id:, brokerage_order_id:, user_id:, user_secret:, extra: {}) ⇒ Object
Get account order detail (V2).
-
#get_user_account_orders_v2(user_id:, user_secret:, account_id:, state: SENTINEL, days: SENTINEL, extra: {}) ⇒ Object
List account orders v2.
-
#get_user_account_orders_v2_with_http_info(user_id:, user_secret:, account_id:, state: SENTINEL, days: SENTINEL, extra: {}) ⇒ Object
List account orders v2.
-
#get_user_account_recent_orders_v2(user_id:, user_secret:, account_id:, only_executed: SENTINEL, extra: {}) ⇒ Object
List account recent orders (V2, last 24 hours only).
-
#get_user_account_recent_orders_v2_with_http_info(user_id:, user_secret:, account_id:, only_executed: SENTINEL, extra: {}) ⇒ Object
List account recent orders (V2, last 24 hours only).
-
#initialize(api_client = ApiClient.default) ⇒ ExperimentalEndpointsApi
constructor
A new instance of ExperimentalEndpointsApi.
-
#sync_brokerage_authorization_transactions(authorization_id:, user_id:, user_secret:, extra: {}) ⇒ Object
Sync transactions for a connection.
-
#sync_brokerage_authorization_transactions_with_http_info(authorization_id:, user_id:, user_secret:, extra: {}) ⇒ Object
Sync transactions for a connection.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ExperimentalEndpointsApi
Returns a new instance of ExperimentalEndpointsApi.
16 17 18 |
# File 'lib/snaptrade/api/experimental_endpoints_api.rb', line 16 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
14 15 16 |
# File 'lib/snaptrade/api/experimental_endpoints_api.rb', line 14 def api_client @api_client end |
Instance Method Details
#get_all_account_positions(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
List all account positions
Returns a list of all positions in the specified account.
The ‘results` list can contain multiple instrument types in the same response, including stocks, ADRs, ETFs, mutual funds, closed-end funds, crypto, futures, and option positions. Use the `instrument.kind` discriminator to determine the schema for each position’s ‘instrument`.
Stock positions may also include ‘cash_equivalent`, and may include `tax_lots` when tax lot data is enabled for the account.
If the connection has become disabled, it can no longer access the latest data from the brokerage, but will continue to return the last available cached state. Please see [this guide](/docs/fix-broken-connections) on how to fix a disabled connection.
34 35 36 37 |
# File 'lib/snaptrade/api/experimental_endpoints_api.rb', line 34 def get_all_account_positions(user_id:, user_secret:, account_id:, extra: {}) data, _status_code, _headers = get_all_account_positions_with_http_info_impl(user_id, user_secret, account_id, extra) data end |
#get_all_account_positions_with_http_info(user_id:, user_secret:, account_id:, extra: {}) ⇒ Object
List all account positions
Returns a list of all positions in the specified account.
The ‘results` list can contain multiple instrument types in the same response, including stocks, ADRs, ETFs, mutual funds, closed-end funds, crypto, futures, and option positions. Use the `instrument.kind` discriminator to determine the schema for each position’s ‘instrument`.
Stock positions may also include ‘cash_equivalent`, and may include `tax_lots` when tax lot data is enabled for the account.
If the connection has become disabled, it can no longer access the latest data from the brokerage, but will continue to return the last available cached state. Please see [this guide](/docs/fix-broken-connections) on how to fix a disabled connection.
53 54 55 |
# File 'lib/snaptrade/api/experimental_endpoints_api.rb', line 53 def get_all_account_positions_with_http_info(user_id:, user_secret:, account_id:, extra: {}) get_all_account_positions_with_http_info_impl(user_id, user_secret, account_id, extra) end |
#get_user_account_order_detail_v2(account_id:, brokerage_order_id:, user_id:, user_secret:, extra: {}) ⇒ Object
Get account order detail (V2)
Returns the detail of a single order using the brokerage order ID provided as a path parameter.
The V2 order response format includes all legs of the order in the ‘legs` list field. If the order is single legged, `legs` will be a list of one leg.
This endpoint is always realtime and does not rely on cached data.
This endpoint only returns orders placed through SnapTrade. In other words, orders placed outside of the SnapTrade network are not returned by this endpoint.
151 152 153 154 |
# File 'lib/snaptrade/api/experimental_endpoints_api.rb', line 151 def get_user_account_order_detail_v2(account_id:, brokerage_order_id:, user_id:, user_secret:, extra: {}) data, _status_code, _headers = get_user_account_order_detail_v2_with_http_info_impl(account_id, brokerage_order_id, user_id, user_secret, extra) data end |
#get_user_account_order_detail_v2_with_http_info(account_id:, brokerage_order_id:, user_id:, user_secret:, extra: {}) ⇒ Object
Get account order detail (V2)
Returns the detail of a single order using the brokerage order ID provided as a path parameter.
The V2 order response format includes all legs of the order in the ‘legs` list field. If the order is single legged, `legs` will be a list of one leg.
This endpoint is always realtime and does not rely on cached data.
This endpoint only returns orders placed through SnapTrade. In other words, orders placed outside of the SnapTrade network are not returned by this endpoint.
172 173 174 |
# File 'lib/snaptrade/api/experimental_endpoints_api.rb', line 172 def get_user_account_order_detail_v2_with_http_info(account_id:, brokerage_order_id:, user_id:, user_secret:, extra: {}) get_user_account_order_detail_v2_with_http_info_impl(account_id, brokerage_order_id, user_id, user_secret, extra) end |
#get_user_account_orders_v2(user_id:, user_secret:, account_id:, state: SENTINEL, days: SENTINEL, extra: {}) ⇒ Object
List account orders v2
Returns a list of recent orders in the specified account.
The V2 order response format will include all legs of each order in the ‘legs` list field. If the order is single legged, `legs` will be a list of one leg.
If the connection has become disabled, it can no longer access the latest data from the brokerage, but will continue to return the last available cached state. Please see [this guide](/docs/fix-broken-connections) on how to fix a disabled connection.
274 275 276 277 278 279 |
# File 'lib/snaptrade/api/experimental_endpoints_api.rb', line 274 def get_user_account_orders_v2(user_id:, user_secret:, account_id:, state: SENTINEL, days: SENTINEL, extra: {}) extra[:state] = state if state != SENTINEL extra[:days] = days if days != SENTINEL data, _status_code, _headers = get_user_account_orders_v2_with_http_info_impl(user_id, user_secret, account_id, extra) data end |
#get_user_account_orders_v2_with_http_info(user_id:, user_secret:, account_id:, state: SENTINEL, days: SENTINEL, extra: {}) ⇒ Object
List account orders v2
Returns a list of recent orders in the specified account.
The V2 order response format will include all legs of each order in the ‘legs` list field. If the order is single legged, `legs` will be a list of one leg.
If the connection has become disabled, it can no longer access the latest data from the brokerage, but will continue to return the last available cached state. Please see [this guide](/docs/fix-broken-connections) on how to fix a disabled connection.
295 296 297 298 299 |
# File 'lib/snaptrade/api/experimental_endpoints_api.rb', line 295 def get_user_account_orders_v2_with_http_info(user_id:, user_secret:, account_id:, state: SENTINEL, days: SENTINEL, extra: {}) extra[:state] = state if state != SENTINEL extra[:days] = days if days != SENTINEL get_user_account_orders_v2_with_http_info_impl(user_id, user_secret, account_id, extra) end |
#get_user_account_recent_orders_v2(user_id:, user_secret:, account_id:, only_executed: SENTINEL, extra: {}) ⇒ Object
List account recent orders (V2, last 24 hours only)
A lightweight endpoint that returns a list of orders executed in the last 24 hours in the specified account using the V2 order format. This endpoint is realtime and can be used to quickly check if account state has recently changed due to an execution, or check status of recently placed orders. Differs from /orders in that it is realtime, and only checks the last 24 hours as opposed to the last 30 days. By default only returns executed orders, but that can be changed by setting only_executed to false. **Because of the cost of realtime requests, each call to this endpoint incurs an additional charge. You can find the exact cost for your API key on the [Customer Dashboard billing page](dashboard.snaptrade.com/settings/billing)**
406 407 408 409 410 |
# File 'lib/snaptrade/api/experimental_endpoints_api.rb', line 406 def get_user_account_recent_orders_v2(user_id:, user_secret:, account_id:, only_executed: SENTINEL, extra: {}) extra[:only_executed] = only_executed if only_executed != SENTINEL data, _status_code, _headers = get_user_account_recent_orders_v2_with_http_info_impl(user_id, user_secret, account_id, extra) data end |
#get_user_account_recent_orders_v2_with_http_info(user_id:, user_secret:, account_id:, only_executed: SENTINEL, extra: {}) ⇒ Object
List account recent orders (V2, last 24 hours only)
A lightweight endpoint that returns a list of orders executed in the last 24 hours in the specified account using the V2 order format. This endpoint is realtime and can be used to quickly check if account state has recently changed due to an execution, or check status of recently placed orders. Differs from /orders in that it is realtime, and only checks the last 24 hours as opposed to the last 30 days. By default only returns executed orders, but that can be changed by setting only_executed to false. **Because of the cost of realtime requests, each call to this endpoint incurs an additional charge. You can find the exact cost for your API key on the [Customer Dashboard billing page](dashboard.snaptrade.com/settings/billing)**
425 426 427 428 |
# File 'lib/snaptrade/api/experimental_endpoints_api.rb', line 425 def get_user_account_recent_orders_v2_with_http_info(user_id:, user_secret:, account_id:, only_executed: SENTINEL, extra: {}) extra[:only_executed] = only_executed if only_executed != SENTINEL get_user_account_recent_orders_v2_with_http_info_impl(user_id, user_secret, account_id, extra) end |
#sync_brokerage_authorization_transactions(authorization_id:, user_id:, user_secret:, extra: {}) ⇒ Object
Sync transactions for a connection
Trigger a transactions sync for all accounts under this connection. Updates will be queued asynchronously. Transactions are not updated intra-day, but calling this endpoint can ensure that the previous day’s transactions have been synced. For more information on sync behaviour, see: docs.snaptrade.com/docs/syncing
519 520 521 522 |
# File 'lib/snaptrade/api/experimental_endpoints_api.rb', line 519 def (authorization_id:, user_id:, user_secret:, extra: {}) data, _status_code, _headers = (, user_id, user_secret, extra) data end |
#sync_brokerage_authorization_transactions_with_http_info(authorization_id:, user_id:, user_secret:, extra: {}) ⇒ Object
Sync transactions for a connection
Trigger a transactions sync for all accounts under this connection. Updates will be queued asynchronously. Transactions are not updated intra-day, but calling this endpoint can ensure that the previous day’s transactions have been synced. For more information on sync behaviour, see: docs.snaptrade.com/docs/syncing
532 533 534 |
# File 'lib/snaptrade/api/experimental_endpoints_api.rb', line 532 def (authorization_id:, user_id:, user_secret:, extra: {}) (, user_id, user_secret, extra) end |