Class: SnapTrade::ExperimentalEndpointsApi
- Inherits:
-
Object
- Object
- SnapTrade::ExperimentalEndpointsApi
- Defined in:
- lib/snaptrade/api/experimental_endpoints_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_user_account_order_detail_v2(brokerage_order_id:, account_id:, user_id:, user_secret:, extra: {}) ⇒ Object
Get account order detail (V2).
-
#get_user_account_order_detail_v2_with_http_info(brokerage_order_id:, account_id:, user_id:, user_secret:, extra: {}) ⇒ Object
Get account order detail (V2).
-
#get_user_account_orders_v2(user_id:, user_secret:, account_id:, state: SENTINEL, days: SENTINEL, extra: {}) ⇒ Object
List account orders v2.
-
#get_user_account_orders_v2_with_http_info(user_id:, user_secret:, account_id:, state: SENTINEL, days: SENTINEL, extra: {}) ⇒ Object
List account orders v2.
-
#get_user_account_recent_orders_v2(user_id:, user_secret:, account_id:, only_executed: SENTINEL, extra: {}) ⇒ Object
List account recent orders (V2, last 24 hours only).
-
#get_user_account_recent_orders_v2_with_http_info(user_id:, user_secret:, account_id:, only_executed: SENTINEL, extra: {}) ⇒ Object
List account recent orders (V2, last 24 hours only).
-
#initialize(api_client = ApiClient.default) ⇒ ExperimentalEndpointsApi
constructor
A new instance of ExperimentalEndpointsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ExperimentalEndpointsApi
Returns a new instance of ExperimentalEndpointsApi.
16 17 18 |
# File 'lib/snaptrade/api/experimental_endpoints_api.rb', line 16 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
14 15 16 |
# File 'lib/snaptrade/api/experimental_endpoints_api.rb', line 14 def api_client @api_client end |
Instance Method Details
#get_user_account_order_detail_v2(brokerage_order_id:, account_id:, user_id:, user_secret:, extra: {}) ⇒ Object
Get account order detail (V2)
Returns the detail of a single order using the external order ID provided in the request body.
The V2 order response format includes all legs of the order in the ‘legs` list field. If the order is single legged, `legs` will be a list of one leg.
This endpoint is always realtime and does not rely on cached data.
This endpoint only returns orders placed through SnapTrade. In other words, orders placed outside of the SnapTrade network are not returned by this endpoint.
37 38 39 40 41 42 43 |
# File 'lib/snaptrade/api/experimental_endpoints_api.rb', line 37 def get_user_account_order_detail_v2(brokerage_order_id:, account_id:, user_id:, user_secret:, extra: {}) _body = {} _body[:brokerage_order_id] = brokerage_order_id if brokerage_order_id != SENTINEL account_information_get_user_account_order_detail_request = _body data, _status_code, _headers = get_user_account_order_detail_v2_with_http_info_impl(account_id, user_id, user_secret, account_information_get_user_account_order_detail_request, extra) data end |
#get_user_account_order_detail_v2_with_http_info(brokerage_order_id:, account_id:, user_id:, user_secret:, extra: {}) ⇒ Object
Get account order detail (V2)
Returns the detail of a single order using the external order ID provided in the request body.
The V2 order response format includes all legs of the order in the ‘legs` list field. If the order is single legged, `legs` will be a list of one leg.
This endpoint is always realtime and does not rely on cached data.
This endpoint only returns orders placed through SnapTrade. In other words, orders placed outside of the SnapTrade network are not returned by this endpoint.
62 63 64 65 66 67 |
# File 'lib/snaptrade/api/experimental_endpoints_api.rb', line 62 def get_user_account_order_detail_v2_with_http_info(brokerage_order_id:, account_id:, user_id:, user_secret:, extra: {}) _body = {} _body[:brokerage_order_id] = brokerage_order_id if brokerage_order_id != SENTINEL account_information_get_user_account_order_detail_request = _body get_user_account_order_detail_v2_with_http_info_impl(account_id, user_id, user_secret, account_information_get_user_account_order_detail_request, extra) end |
#get_user_account_orders_v2(user_id:, user_secret:, account_id:, state: SENTINEL, days: SENTINEL, extra: {}) ⇒ Object
List account orders v2
Returns a list of recent orders in the specified account.
The V2 order response format will include all legs of each order in the ‘legs` list field. If the order is single legged, `legs` will be a list of one leg.
If the connection has become disabled, it can no longer access the latest data from the brokerage, but will continue to return the last available cached state. Please see [this guide](/docs/fix-broken-connections) on how to fix a disabled connection.
172 173 174 175 176 177 |
# File 'lib/snaptrade/api/experimental_endpoints_api.rb', line 172 def get_user_account_orders_v2(user_id:, user_secret:, account_id:, state: SENTINEL, days: SENTINEL, extra: {}) extra[:state] = state if state != SENTINEL extra[:days] = days if days != SENTINEL data, _status_code, _headers = get_user_account_orders_v2_with_http_info_impl(user_id, user_secret, account_id, extra) data end |
#get_user_account_orders_v2_with_http_info(user_id:, user_secret:, account_id:, state: SENTINEL, days: SENTINEL, extra: {}) ⇒ Object
List account orders v2
Returns a list of recent orders in the specified account.
The V2 order response format will include all legs of each order in the ‘legs` list field. If the order is single legged, `legs` will be a list of one leg.
If the connection has become disabled, it can no longer access the latest data from the brokerage, but will continue to return the last available cached state. Please see [this guide](/docs/fix-broken-connections) on how to fix a disabled connection.
193 194 195 196 197 |
# File 'lib/snaptrade/api/experimental_endpoints_api.rb', line 193 def get_user_account_orders_v2_with_http_info(user_id:, user_secret:, account_id:, state: SENTINEL, days: SENTINEL, extra: {}) extra[:state] = state if state != SENTINEL extra[:days] = days if days != SENTINEL get_user_account_orders_v2_with_http_info_impl(user_id, user_secret, account_id, extra) end |
#get_user_account_recent_orders_v2(user_id:, user_secret:, account_id:, only_executed: SENTINEL, extra: {}) ⇒ Object
List account recent orders (V2, last 24 hours only)
A lightweight endpoint that returns a list of orders executed in the last 24 hours in the specified account using the V2 order format. This endpoint is realtime and can be used to quickly check if account state has recently changed due to an execution, or check status of recently placed orders. Differs from /orders in that it is realtime, and only checks the last 24 hours as opposed to the last 30 days. By default only returns executed orders, but that can be changed by setting only_executed to false. **Because of the cost of realtime requests, each call to this endpoint incurs an additional charge. You can find the exact cost for your API key on the [Customer Dashboard billing page](dashboard.snaptrade.com/settings/billing)**
304 305 306 307 308 |
# File 'lib/snaptrade/api/experimental_endpoints_api.rb', line 304 def get_user_account_recent_orders_v2(user_id:, user_secret:, account_id:, only_executed: SENTINEL, extra: {}) extra[:only_executed] = only_executed if only_executed != SENTINEL data, _status_code, _headers = get_user_account_recent_orders_v2_with_http_info_impl(user_id, user_secret, account_id, extra) data end |
#get_user_account_recent_orders_v2_with_http_info(user_id:, user_secret:, account_id:, only_executed: SENTINEL, extra: {}) ⇒ Object
List account recent orders (V2, last 24 hours only)
A lightweight endpoint that returns a list of orders executed in the last 24 hours in the specified account using the V2 order format. This endpoint is realtime and can be used to quickly check if account state has recently changed due to an execution, or check status of recently placed orders. Differs from /orders in that it is realtime, and only checks the last 24 hours as opposed to the last 30 days. By default only returns executed orders, but that can be changed by setting only_executed to false. **Because of the cost of realtime requests, each call to this endpoint incurs an additional charge. You can find the exact cost for your API key on the [Customer Dashboard billing page](dashboard.snaptrade.com/settings/billing)**
323 324 325 326 |
# File 'lib/snaptrade/api/experimental_endpoints_api.rb', line 323 def get_user_account_recent_orders_v2_with_http_info(user_id:, user_secret:, account_id:, only_executed: SENTINEL, extra: {}) extra[:only_executed] = only_executed if only_executed != SENTINEL get_user_account_recent_orders_v2_with_http_info_impl(user_id, user_secret, account_id, extra) end |