Class: SnapTrade::OrderUpdatedResponseOrder

Inherits:
Object
  • Object
show all
Defined in:
lib/snaptrade/models/order_updated_response_order.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ OrderUpdatedResponseOrder

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 169

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SnapTrade::OrderUpdatedResponseOrder` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SnapTrade::OrderUpdatedResponseOrder`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'brokerage_order_id')
    self.brokerage_order_id = attributes[:'brokerage_order_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'universal_symbol')
    self.universal_symbol = attributes[:'universal_symbol']
  end

  if attributes.key?(:'option_symbol')
    self.option_symbol = attributes[:'option_symbol']
  end

  if attributes.key?(:'quote_universal_symbol')
    self.quote_universal_symbol = attributes[:'quote_universal_symbol']
  end

  if attributes.key?(:'quote_currency')
    self.quote_currency = attributes[:'quote_currency']
  end

  if attributes.key?(:'action')
    self.action = attributes[:'action']
  end

  if attributes.key?(:'total_quantity')
    self.total_quantity = attributes[:'total_quantity']
  end

  if attributes.key?(:'open_quantity')
    self.open_quantity = attributes[:'open_quantity']
  end

  if attributes.key?(:'canceled_quantity')
    self.canceled_quantity = attributes[:'canceled_quantity']
  end

  if attributes.key?(:'filled_quantity')
    self.filled_quantity = attributes[:'filled_quantity']
  end

  if attributes.key?(:'execution_price')
    self.execution_price = attributes[:'execution_price']
  end

  if attributes.key?(:'limit_price')
    self.limit_price = attributes[:'limit_price']
  end

  if attributes.key?(:'stop_price')
    self.stop_price = attributes[:'stop_price']
  end

  if attributes.key?(:'trailing_stop')
    self.trailing_stop = attributes[:'trailing_stop']
  end

  if attributes.key?(:'order_type')
    self.order_type = attributes[:'order_type']
  end

  if attributes.key?(:'time_in_force')
    self.time_in_force = attributes[:'time_in_force']
  end

  if attributes.key?(:'time_placed')
    self.time_placed = attributes[:'time_placed']
  end

  if attributes.key?(:'time_updated')
    self.time_updated = attributes[:'time_updated']
  end

  if attributes.key?(:'time_executed')
    self.time_executed = attributes[:'time_executed']
  end

  if attributes.key?(:'expiry_date')
    self.expiry_date = attributes[:'expiry_date']
  end

  if attributes.key?(:'symbol')
    self.symbol = attributes[:'symbol']
  end

  if attributes.key?(:'child_brokerage_order_ids')
    self.child_brokerage_order_ids = attributes[:'child_brokerage_order_ids']
  end
end

Instance Attribute Details

#actionObject

The action describes the intent or side of a trade. This is usually ‘BUY` or `SELL` but can include other potential values like the following depending on the specific brokerage. - BUY - SELL - BUY_COVER - SELL_SHORT - BUY_OPEN - BUY_CLOSE - SELL_OPEN - SELL_CLOSE



30
31
32
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 30

def action
  @action
end

#brokerage_order_idObject

Order ID returned by brokerage. This is the unique identifier for the order in the brokerage system.



16
17
18
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 16

def brokerage_order_id
  @brokerage_order_id
end

#canceled_quantityObject

The number of shares or contracts that have been canceled. Can be a decimal number for fractional shares.



39
40
41
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 39

def canceled_quantity
  @canceled_quantity
end

#child_brokerage_order_idsObject

Returns the value of attribute child_brokerage_order_ids.



76
77
78
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 76

def child_brokerage_order_ids
  @child_brokerage_order_ids
end

#execution_priceObject

The price at which the order was executed. For option orders, this represents the price per share.



45
46
47
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 45

def execution_price
  @execution_price
end

#expiry_dateObject

The time the order expires. This value is not always available from the brokerage.



71
72
73
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 71

def expiry_date
  @expiry_date
end

#filled_quantityObject

The number of shares or contracts that have been filled. Can be a decimal number for fractional shares.



42
43
44
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 42

def filled_quantity
  @filled_quantity
end

#limit_priceObject

The limit price is maximum price one is willing to pay for a buy order or the minimum price one is willing to accept for a sell order. Should only apply to ‘Limit` and `StopLimit` orders. For option orders, this represents the price per share.



48
49
50
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 48

def limit_price
  @limit_price
end

#open_quantityObject

The number of shares or contracts that are still open (waiting for execution). Can be a decimal number for fractional shares.



36
37
38
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 36

def open_quantity
  @open_quantity
end

#option_symbolObject

Returns the value of attribute option_symbol.



23
24
25
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 23

def option_symbol
  @option_symbol
end

#order_typeObject

The type of order placed. The most common values are ‘Market`, `Limit`, `Stop`, and `StopLimit`. We try our best to map brokerage order types to these values. When mapping fails, we will return the brokerage’s order type value.



56
57
58
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 56

def order_type
  @order_type
end

#quote_currencyObject

Returns the value of attribute quote_currency.



27
28
29
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 27

def quote_currency
  @quote_currency
end

#quote_universal_symbolObject

Returns the value of attribute quote_universal_symbol.



25
26
27
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 25

def quote_universal_symbol
  @quote_universal_symbol
end

#statusObject

Indicates the status of an order. SnapTrade does a best effort to map brokerage statuses to statuses in this enum. Possible values include: - NONE - PENDING - ACCEPTED - FAILED - REJECTED - CANCELED - PARTIAL_CANCELED - CANCEL_PENDING - EXECUTED - PARTIAL - REPLACE_PENDING - REPLACED - EXPIRED - QUEUED - TRIGGERED - ACTIVATED



19
20
21
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 19

def status
  @status
end

#stop_priceObject

The stop price is the price at which a stop order is triggered. Should only apply to ‘Stop` and `StopLimit` orders. For option orders, this represents the price per share.



51
52
53
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 51

def stop_price
  @stop_price
end

#symbolObject

A unique ID for the security within SnapTrade, scoped to the brokerage account that the security belongs to. This is a legacy field and should not be used. Do not rely on this being a stable ID as it can change.



74
75
76
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 74

def symbol
  @symbol
end

#time_executedObject

The time the order was executed in the brokerage system. This value is not always available from the brokerage.



68
69
70
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 68

def time_executed
  @time_executed
end

#time_in_forceObject

The Time in Force type for the order. This field indicates how long the order will remain active before it is executed or expires. We try our best to map brokerage time in force values to the following. When mapping fails, we will return the brokerage’s time in force value. - ‘Day` - Day. The order is valid only for the trading day on which it is placed. - `GTC` - Good Til Canceled. The order is valid until it is executed or canceled. - `FOK` - Fill Or Kill. The order must be executed in its entirety immediately or be canceled completely. - `IOC` - Immediate Or Cancel. The order must be executed immediately. Any portion of the order that cannot be filled immediately will be canceled. - `GTD` - Good Til Date. The order is valid until the specified date. - `MOO` - Market On Open. The order is to be executed at the day’s opening price. - ‘EHP` - Extended Hours P.M. The order is to be placed during extended hour trading, after markets close.



59
60
61
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 59

def time_in_force
  @time_in_force
end

#time_placedObject

The time the order was placed. This is the time the order was submitted to the brokerage.



62
63
64
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 62

def time_placed
  @time_placed
end

#time_updatedObject

The time the order was last updated in the brokerage system. This value is not always available from the brokerage.



65
66
67
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 65

def time_updated
  @time_updated
end

#total_quantityObject

The total number of shares or contracts of the order. This should be the sum of the filled, canceled, and open quantities. Can be a decimal number for fractional shares.



33
34
35
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 33

def total_quantity
  @total_quantity
end

#trailing_stopObject

Returns the value of attribute trailing_stop.



53
54
55
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 53

def trailing_stop
  @trailing_stop
end

#universal_symbolObject

Returns the value of attribute universal_symbol.



21
22
23
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 21

def universal_symbol
  @universal_symbol
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



108
109
110
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 108

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 79

def self.attribute_map
  {
    :'brokerage_order_id' => :'brokerage_order_id',
    :'status' => :'status',
    :'universal_symbol' => :'universal_symbol',
    :'option_symbol' => :'option_symbol',
    :'quote_universal_symbol' => :'quote_universal_symbol',
    :'quote_currency' => :'quote_currency',
    :'action' => :'action',
    :'total_quantity' => :'total_quantity',
    :'open_quantity' => :'open_quantity',
    :'canceled_quantity' => :'canceled_quantity',
    :'filled_quantity' => :'filled_quantity',
    :'execution_price' => :'execution_price',
    :'limit_price' => :'limit_price',
    :'stop_price' => :'stop_price',
    :'trailing_stop' => :'trailing_stop',
    :'order_type' => :'order_type',
    :'time_in_force' => :'time_in_force',
    :'time_placed' => :'time_placed',
    :'time_updated' => :'time_updated',
    :'time_executed' => :'time_executed',
    :'expiry_date' => :'expiry_date',
    :'symbol' => :'symbol',
    :'child_brokerage_order_ids' => :'child_brokerage_order_ids'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



333
334
335
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 333

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



161
162
163
164
165
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 161

def self.openapi_all_of
  [
  :'AccountOrderRecord'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 142

def self.openapi_nullable
  Set.new([
    :'total_quantity',
    :'open_quantity',
    :'canceled_quantity',
    :'filled_quantity',
    :'execution_price',
    :'limit_price',
    :'stop_price',
    :'trailing_stop',
    :'order_type',
    :'time_updated',
    :'time_executed',
    :'expiry_date',
    :'child_brokerage_order_ids'
  ])
end

.openapi_typesObject

Attribute type mapping.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 113

def self.openapi_types
  {
    :'brokerage_order_id' => :'String',
    :'status' => :'AccountOrderRecordStatus',
    :'universal_symbol' => :'AccountOrderRecordUniversalSymbol',
    :'option_symbol' => :'AccountOrderRecordOptionSymbol',
    :'quote_universal_symbol' => :'AccountOrderRecordQuoteUniversalSymbol',
    :'quote_currency' => :'AccountOrderRecordQuoteCurrency',
    :'action' => :'String',
    :'total_quantity' => :'String',
    :'open_quantity' => :'String',
    :'canceled_quantity' => :'String',
    :'filled_quantity' => :'String',
    :'execution_price' => :'Float',
    :'limit_price' => :'Float',
    :'stop_price' => :'Float',
    :'trailing_stop' => :'AccountOrderRecordTrailingStop',
    :'order_type' => :'String',
    :'time_in_force' => :'String',
    :'time_placed' => :'Time',
    :'time_updated' => :'Time',
    :'time_executed' => :'Time',
    :'expiry_date' => :'Time',
    :'symbol' => :'String',
    :'child_brokerage_order_ids' => :'AccountOrderRecordChildBrokerageOrderIds'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 290

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      brokerage_order_id == o.brokerage_order_id &&
      status == o.status &&
      universal_symbol == o.universal_symbol &&
      option_symbol == o.option_symbol &&
      quote_universal_symbol == o.quote_universal_symbol &&
      quote_currency == o.quote_currency &&
      action == o.action &&
      total_quantity == o.total_quantity &&
      open_quantity == o.open_quantity &&
      canceled_quantity == o.canceled_quantity &&
      filled_quantity == o.filled_quantity &&
      execution_price == o.execution_price &&
      limit_price == o.limit_price &&
      stop_price == o.stop_price &&
      trailing_stop == o.trailing_stop &&
      order_type == o.order_type &&
      time_in_force == o.time_in_force &&
      time_placed == o.time_placed &&
      time_updated == o.time_updated &&
      time_executed == o.time_executed &&
      expiry_date == o.expiry_date &&
      symbol == o.symbol &&
      child_brokerage_order_ids == o.child_brokerage_order_ids
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 364

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = SnapTrade.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



435
436
437
438
439
440
441
442
443
444
445
446
447
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 435

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 340

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


320
321
322
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 320

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



326
327
328
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 326

def hash
  [brokerage_order_id, status, universal_symbol, option_symbol, quote_universal_symbol, quote_currency, action, total_quantity, open_quantity, canceled_quantity, filled_quantity, execution_price, limit_price, stop_price, trailing_stop, order_type, time_in_force, time_placed, time_updated, time_executed, expiry_date, symbol, child_brokerage_order_ids].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



277
278
279
280
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 277

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



411
412
413
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 411

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



417
418
419
420
421
422
423
424
425
426
427
428
429
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 417

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



405
406
407
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 405

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



284
285
286
# File 'lib/snaptrade/models/order_updated_response_order.rb', line 284

def valid?
  true
end